"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QTableWidget(QTableView):
    """
    https://doc.qt.io/qt-6/qtablewidget.html

    **Detailed Description**

    ![](images/windows-tableview.png)

    Table widgets provide standard table display facilities for applications.
    The items in a QTableWidget are provided by **QTableWidgetItem** .

    If you want a table that uses your own data model you should use
    **QTableView**  rather than this class.

    Table widgets can be constructed with the required numbers of rows and
    columns:

    tableWidget = new **QTableWidget** (12, 3, this);

    Alternatively, tables can be constructed without a given size and resized
    later:

    tableWidget = new **QTableWidget** (this);
    tableWidget->setRowCount(10);
            tableWidget->setColumnCount(5);

    Items are created outside the table (with no parent widget) and inserted
    into the table with **setItem** ():

    **QTableWidgetItem**  *newItem = new **QTableWidgetItem** (tr("%1").arg(
    (row+1)*(column+1)));
            tableWidget->setItem(row, column, newItem);

    If you want to enable sorting in your table widget, do so after you have
    populated it with items, otherwise sorting may interfere with the insertion
    order (see **setItem** () for details).

    Tables can be given both horizontal and vertical headers. The simplest way
    to create the headers is to supply a list of strings to the
    **setHorizontalHeaderLabels** () and **setVerticalHeaderLabels** ()
    functions. These will provide simple textual headers for the table's columns
    and rows. More sophisticated headers can be created from existing table
    items that are usually constructed outside the table. For example, we can
    construct a table item with an icon and aligned text, and use it as the
    header for a particular column:

    **QTableWidgetItem**  *cubesHeaderItem = new **QTableWidgetItem**
    (tr("Cubes"));
            cubesHeaderItem->setIcon(**QIcon** (**QPixmap**
    (":/Images/cubed.png")));
    cubesHeaderItem->setTextAlignment(Qt::AlignVCenter);

    The number of rows in the table can be found with **rowCount** (), and the
    number of columns with **columnCount** (). The table can be cleared with the
    **clear** () function.

    **See also** **QTableWidgetItem** , **QTableView** , and **Model/View
    Programming** .
    """

    @typing.overload
    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#QTableWidget

        **QTableWidget::QTableWidget(QWidget * parent = nullptr)**

        Creates a new table view with the given **parent**.
        """
        ...

    @typing.overload
    def __init__(
        self, rows: int, columns: int, parent: typing.Optional[QWidget] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#QTableWidget-1

        **QTableWidget::QTableWidget(int rows , int columns , QWidget * parent =
        nullptr)**

        Creates a new table view with the given **rows** and **columns** , and
        with the given **parent**.
        """
        ...

    def isPersistentEditorOpen(self, item: QTableWidgetItem) -> bool:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#isPersistentEditorOpen

        **[since 5.10] bool
        QTableWidget::isPersistentEditorOpen(QTableWidgetItem * item ) const**

        Returns whether a persistent editor is open for item **item**.

        This function was introduced in Qt 5.10.

        **See also** **openPersistentEditor** () and **closePersistentEditor**
        ().
        """
        ...

    def dropEvent(self, event: QtGui.QDropEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#dropEvent

        **[override virtual protected] void QTableWidget::dropEvent(QDropEvent *
        event )**

        Reimplements: **QAbstractItemView::dropEvent** (QDropEvent *event).
        """
        ...

    def event(self, e: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#event

        **[override virtual protected] bool QTableWidget::event(QEvent * e )**

        Reimplements: **QAbstractItemView::event** (QEvent *event).
        """
        ...

    def itemFromIndex(self, index: QtCore.QModelIndex) -> QTableWidgetItem:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#itemFromIndex

        **QTableWidgetItem *QTableWidget::itemFromIndex(const QModelIndex &
        index ) const**

        Returns a pointer to the **QTableWidgetItem**  associated with the given
        **index**.
        """
        ...

    def indexFromItem(self, item: QTableWidgetItem) -> QtCore.QModelIndex:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#indexFromItem

        **QModelIndex QTableWidget::indexFromItem(const QTableWidgetItem * item
        ) const**

        Returns the **QModelIndex**  associated with the given **item**.

        **Note:** In Qt versions prior to 5.10, this function took a non-`const`
        **item**.
        """
        ...

    def items(self, data: QtCore.QMimeData) -> typing.List[QTableWidgetItem]:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#items

        **QList<QTableWidgetItem *> QTableWidget::items(const QMimeData * data )
        const**

        Returns a list of pointers to the items contained in the **data**
        object. If the object was not created by a **QTreeWidget**  in the same
        process, the list is empty.
        """
        ...

    def supportedDropActions(self) -> QtCore.Qt.DropAction:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#supportedDropActions

        **[virtual protected] Qt::DropActions
        QTableWidget::supportedDropActions() const**

        Returns the drop actions supported by this view.

        **See also** **Qt::DropActions** .
        """
        ...

    def dropMimeData(
        self,
        row: int,
        column: int,
        data: QtCore.QMimeData,
        action: QtCore.Qt.DropAction,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#dropMimeData

        **[virtual protected] bool QTableWidget::dropMimeData(int row , int
        column , const QMimeData * data , Qt::DropAction action )**

        Handles the **data** supplied by a drag and drop operation that ended
        with the given **action** in the given **row** and **column**. Returns
        `true` if the data and action can be handled by the model; otherwise
        returns `false`.

        **See also** **supportedDropActions** ().
        """
        ...

    def mimeData(self, items: typing.Iterable[QTableWidgetItem]) -> QtCore.QMimeData:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#mimeData

        **[virtual protected] QMimeData *QTableWidget::mimeData(const
        QList<QTableWidgetItem *> & items ) const**

        Returns an object that contains a serialized description of the
        specified **items**. The format used to describe the items is obtained
        from the **mimeTypes** () function.

        If the list of items is empty, `nullptr` is returned rather than a
        serialized empty list.
        """
        ...

    def mimeTypes(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#mimeTypes

        **[virtual protected] QStringList QTableWidget::mimeTypes() const**

        Returns a list of MIME types that can be used to describe a list of
        tablewidget items.

        **See also** **mimeData** ().
        """
        ...

    def clearContents(self) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#clearContents

        **[slot] void QTableWidget::clearContents()**

        Removes all items not in the headers from the view. This will also
        remove all selections. The table dimensions stay the same.
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#clear

        **[slot] void QTableWidget::clear()**

        Removes all items in the view. This will also remove all selections and
        headers. If you don't want to remove the headers, use
        **QTableWidget::clearContents** (). The table dimensions stay the same.
        """
        ...

    def removeColumn(self, column: int) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#removeColumn

        **[slot] void QTableWidget::removeColumn(int column )**

        Removes the column **column** and all its items from the table.
        """
        ...

    def removeRow(self, row: int) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#removeRow

        **[slot] void QTableWidget::removeRow(int row )**

        Removes the row **row** and all its items from the table.
        """
        ...

    def insertColumn(self, column: int) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#insertColumn

        **[slot] void QTableWidget::insertColumn(int column )**

        Inserts an empty column into the table at **column**.
        """
        ...

    def insertRow(self, row: int) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#insertRow

        **[slot] void QTableWidget::insertRow(int row )**

        Inserts an empty row into the table at **row**.
        """
        ...

    def scrollToItem(
        self, item: QTableWidgetItem, hint: QAbstractItemView.ScrollHint = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#scrollToItem

        **[slot] void QTableWidget::scrollToItem(const QTableWidgetItem * item ,
        QAbstractItemView::ScrollHint hint = EnsureVisible)**

        Scrolls the view if necessary to ensure that the **item** is visible.
        The **hint** parameter specifies more precisely where the **item**
        should be located after the operation.
        """
        ...

    def setItemPrototype(self, item: QTableWidgetItem) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#setItemPrototype

        **void QTableWidget::setItemPrototype(const QTableWidgetItem * item )**

        Sets the item prototype for the table to the specified **item**.

        The table widget will use the item prototype clone function when it
        needs to create a new table item. For example when the user is editing
        in an empty cell. This is useful when you have a **QTableWidgetItem**
        subclass and want to make sure that **QTableWidget**  creates instances
        of your subclass.

        The table takes ownership of the prototype.

        **See also** **itemPrototype** ().
        """
        ...

    def itemPrototype(self) -> QTableWidgetItem:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#itemPrototype

        **const QTableWidgetItem *QTableWidget::itemPrototype() const**

        Returns the item prototype used by the table.

        **See also** **setItemPrototype** ().
        """
        ...

    def visualItemRect(self, item: QTableWidgetItem) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#visualItemRect

        **QRect QTableWidget::visualItemRect(const QTableWidgetItem * item )
        const**

        Returns the rectangle on the viewport occupied by the item at **item**.
        """
        ...

    @typing.overload
    def itemAt(self, p: QtCore.QPoint) -> QTableWidgetItem:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#itemAt

        **QTableWidgetItem *QTableWidget::itemAt(const QPoint & point ) const**

        Returns a pointer to the item at the given **point** , or returns
        `nullptr` if **point** is not covered by an item in the table widget.

        **See also** **item** ().
        """
        ...

    @typing.overload
    def itemAt(self, ax: int, ay: int) -> QTableWidgetItem:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#itemAt-1

        **QTableWidgetItem *QTableWidget::itemAt(int ax , int ay ) const**

        Returns the item at the position equivalent to **QPoint** ( **ax** ,
        **ay** ) in the table widget's coordinate system, or returns `nullptr`
        if the specified point is not covered by an item in the table widget.

        **See also** **item** ().
        """
        ...

    def visualColumn(self, logicalColumn: int) -> int:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#visualColumn

        **int QTableWidget::visualColumn(int logicalColumn ) const**

        Returns the visual column of the given **logicalColumn**.
        """
        ...

    def visualRow(self, logicalRow: int) -> int:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#visualRow

        **int QTableWidget::visualRow(int logicalRow ) const**

        Returns the visual row of the given **logicalRow**.
        """
        ...

    def findItems(
        self, text: str, flags: QtCore.Qt.MatchFlag
    ) -> typing.List[QTableWidgetItem]:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#findItems

        **QList<QTableWidgetItem *> QTableWidget::findItems(const QString & text
        , Qt::MatchFlags flags ) const**

        Finds items that matches the **text** using the given **flags**.
        """
        ...

    def selectedItems(self) -> typing.List[QTableWidgetItem]:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#selectedItems

        **QList<QTableWidgetItem *> QTableWidget::selectedItems() const**

        Returns a list of all selected items.

        This function returns a list of pointers to the contents of the selected
        cells. Use the **selectedIndexes** () function to retrieve the complete
        selection **including** empty cells.

        **See also** **selectedIndexes** ().
        """
        ...

    def selectedRanges(self) -> typing.List[QTableWidgetSelectionRange]:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#selectedRanges

        **QList<QTableWidgetSelectionRange> QTableWidget::selectedRanges()
        const**

        Returns a list of all selected ranges.

        **See also** **QTableWidgetSelectionRange** .
        """
        ...

    def setRangeSelected(self, range: QTableWidgetSelectionRange, select: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#setRangeSelected

        **void QTableWidget::setRangeSelected(const QTableWidgetSelectionRange &
        range , bool select )**

        Selects or deselects the **range** depending on **select**.
        """
        ...

    def removeCellWidget(self, arow: int, acolumn: int) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#removeCellWidget

        **void QTableWidget::removeCellWidget(int row , int column )**

        Removes the widget set on the cell indicated by **row** and **column**.
        """
        ...

    def setCellWidget(self, row: int, column: int, widget: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#setCellWidget

        **void QTableWidget::setCellWidget(int row , int column , QWidget *
        widget )**

        Sets the given **widget** to be displayed in the cell in the given
        **row** and **column** , passing the ownership of the widget to the
        table.

        If cell widget A is replaced with cell widget B, cell widget A will be
        deleted. For example, in the code snippet below, the **QLineEdit**
        object will be deleted.

        setCellWidget(row, column, new **QLineEdit** );
            ...
        setCellWidget(row, column, new **QTextEdit** );

        **See also** **cellWidget** ().
        """
        ...

    def cellWidget(self, row: int, column: int) -> QWidget:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#cellWidget

        **QWidget *QTableWidget::cellWidget(int row , int column ) const**

        Returns the widget displayed in the cell in the given **row** and
        **column**.

        **Note:** The table takes ownership of the widget.

        **See also** **setCellWidget** ().
        """
        ...

    def closePersistentEditor(self, item: QTableWidgetItem) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#closePersistentEditor

        **void QTableWidget::closePersistentEditor(QTableWidgetItem * item )**

        Closes the persistent editor for **item**.

        **See also** **openPersistentEditor** () and **isPersistentEditorOpen**
        ().
        """
        ...

    def openPersistentEditor(self, item: QTableWidgetItem) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#openPersistentEditor

        **void QTableWidget::openPersistentEditor(QTableWidgetItem * item )**

        Opens an editor for the give **item**. The editor remains open after
        editing.

        **See also** **closePersistentEditor** () and **isPersistentEditorOpen**
        ().
        """
        ...

    def editItem(self, item: QTableWidgetItem) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#editItem

        **void QTableWidget::editItem(QTableWidgetItem * item )**

        Starts editing the **item** if it is editable.
        """
        ...

    def isSortingEnabled(self) -> bool:
        ...

    def setSortingEnabled(self, enable: bool) -> None:
        ...

    def sortItems(self, column: int, order: QtCore.Qt.SortOrder = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#sortItems

        **void QTableWidget::sortItems(int column , Qt::SortOrder order =
        Qt::AscendingOrder)**

        Sorts all the rows in the table widget based on **column** and
        **order**.
        """
        ...

    @typing.overload
    def setCurrentCell(self, row: int, column: int) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#setCurrentCell

        **void QTableWidget::setCurrentCell(int row , int column )**

        Sets the current cell to be the cell at position ( **row** , **column**
        ).

        Depending on the current **selection mode** , the cell may also be
        selected.

        **See also** **setCurrentItem** (), **currentRow** (), and
        **currentColumn** ().
        """
        ...

    @typing.overload
    def setCurrentCell(
        self, row: int, column: int, command: QtCore.QItemSelectionModel.SelectionFlag
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#setCurrentCell-1

        **void QTableWidget::setCurrentCell(int row , int column ,
        QItemSelectionModel::SelectionFlags command )**

        Sets the current cell to be the cell at position ( **row** , **column**
        ), using the given **command**.

        **See also** **setCurrentItem** (), **currentRow** (), and
        **currentColumn** ().
        """
        ...

    @typing.overload
    def setCurrentItem(self, item: QTableWidgetItem) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#setCurrentItem

        **void QTableWidget::setCurrentItem(QTableWidgetItem * item )**

        Sets the current item to **item**.

        Unless the selection mode is **NoSelection** , the item is also
        selected.

        **See also** **currentItem** () and **setCurrentCell** ().
        """
        ...

    @typing.overload
    def setCurrentItem(
        self, item: QTableWidgetItem, command: QtCore.QItemSelectionModel.SelectionFlag
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#setCurrentItem-1

        **void QTableWidget::setCurrentItem(QTableWidgetItem * item ,
        QItemSelectionModel::SelectionFlags command )**

        Sets the current item to be **item** , using the given **command**.

        **See also** **currentItem** () and **setCurrentCell** ().
        """
        ...

    def currentItem(self) -> QTableWidgetItem:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#currentItem

        **QTableWidgetItem *QTableWidget::currentItem() const**

        Returns the current item.

        **See also** **setCurrentItem** ().
        """
        ...

    def currentColumn(self) -> int:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#currentColumn

        **int QTableWidget::currentColumn() const**

        Returns the column of the current item.

        **See also** **currentRow** () and **setCurrentCell** ().
        """
        ...

    def currentRow(self) -> int:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#currentRow

        **int QTableWidget::currentRow() const**

        Returns the row of the current item.

        **See also** **currentColumn** () and **setCurrentCell** ().
        """
        ...

    def setHorizontalHeaderLabels(self, labels: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#setHorizontalHeaderLabels

        **void QTableWidget::setHorizontalHeaderLabels(const QStringList &
        labels )**

        Sets the horizontal header labels using **labels**.
        """
        ...

    def setVerticalHeaderLabels(self, labels: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#setVerticalHeaderLabels

        **void QTableWidget::setVerticalHeaderLabels(const QStringList & labels
        )**

        Sets the vertical header labels using **labels**.
        """
        ...

    def takeHorizontalHeaderItem(self, column: int) -> QTableWidgetItem:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#takeHorizontalHeaderItem

        **QTableWidgetItem *QTableWidget::takeHorizontalHeaderItem(int column
        )**

        Removes the horizontal header item at **column** from the header without
        deleting it.
        """
        ...

    def setHorizontalHeaderItem(self, column: int, item: QTableWidgetItem) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#setHorizontalHeaderItem

        **void QTableWidget::setHorizontalHeaderItem(int column ,
        QTableWidgetItem * item )**

        Sets the horizontal header item for column **column** to **item**. If
        necessary, the column count is increased to fit the item. The previous
        header item (if there was one) is deleted.

        **See also** **horizontalHeaderItem** ().
        """
        ...

    def horizontalHeaderItem(self, column: int) -> QTableWidgetItem:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#horizontalHeaderItem

        **QTableWidgetItem *QTableWidget::horizontalHeaderItem(int column )
        const**

        Returns the horizontal header item for column, **column** , if one has
        been set; otherwise returns `nullptr`.

        **See also** **setHorizontalHeaderItem** ().
        """
        ...

    def takeVerticalHeaderItem(self, row: int) -> QTableWidgetItem:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#takeVerticalHeaderItem

        **QTableWidgetItem *QTableWidget::takeVerticalHeaderItem(int row )**

        Removes the vertical header item at **row** from the header without
        deleting it.
        """
        ...

    def setVerticalHeaderItem(self, row: int, item: QTableWidgetItem) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#setVerticalHeaderItem

        **void QTableWidget::setVerticalHeaderItem(int row , QTableWidgetItem *
        item )**

        Sets the vertical header item for row **row** to **item**.

        **See also** **verticalHeaderItem** ().
        """
        ...

    def verticalHeaderItem(self, row: int) -> QTableWidgetItem:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#verticalHeaderItem

        **QTableWidgetItem *QTableWidget::verticalHeaderItem(int row ) const**

        Returns the vertical header item for row **row**.

        **See also** **setVerticalHeaderItem** ().
        """
        ...

    def takeItem(self, row: int, column: int) -> QTableWidgetItem:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#takeItem

        **QTableWidgetItem *QTableWidget::takeItem(int row , int column )**

        Removes the item at **row** and **column** from the table without
        deleting it.
        """
        ...

    def setItem(self, row: int, column: int, item: QTableWidgetItem) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#setItem

        **void QTableWidget::setItem(int row , int column , QTableWidgetItem *
        item )**

        Sets the item for the given **row** and **column** to **item**.

        The table takes ownership of the item.

        Note that if sorting is enabled (see **sortingEnabled** ) and **column**
        is the current sort column, the **row** will be moved to the sorted
        position determined by **item**.

        If you want to set several items of a particular row (say, by calling
        setItem() in a loop), you may want to turn off sorting before doing so,
        and turn it back on afterwards; this will allow you to use the same
        **row** argument for all items in the same row (i.e. setItem() will not
        move the row).

        **See also** **item** () and **takeItem** ().
        """
        ...

    def item(self, row: int, column: int) -> QTableWidgetItem:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#item

        **QTableWidgetItem *QTableWidget::item(int row , int column ) const**

        Returns the item for the given **row** and **column** if one has been
        set; otherwise returns `nullptr`.

        **See also** **setItem** ().
        """
        ...

    def column(self, item: QTableWidgetItem) -> int:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#column

        **int QTableWidget::column(const QTableWidgetItem * item ) const**

        Returns the column for the **item**.
        """
        ...

    def row(self, item: QTableWidgetItem) -> int:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#row

        **int QTableWidget::row(const QTableWidgetItem * item ) const**

        Returns the row for the **item**.
        """
        ...

    def columnCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#columnCount

        **int QTableWidget::columnCount() const**

        Returns the number of columns.

        **Note:** Getter function for property columnCount.

        **See also** **setColumnCount** ().
        """
        ...

    def setColumnCount(self, columns: int) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#setColumnCount

        **void QTableWidget::setColumnCount(int columns )**

        Sets the number of columns in this table's model to **columns**. If this
        is less than **columnCount** (), the data in the unwanted columns is
        discarded.

        **Note:** Setter function for property **columnCount** .

        **See also** **columnCount** () and **setRowCount** ().
        """
        ...

    def rowCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#rowCount

        **int QTableWidget::rowCount() const**

        Returns the number of rows.

        **Note:** Getter function for property rowCount.

        **See also** **setRowCount** ().
        """
        ...

    def setRowCount(self, rows: int) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#setRowCount

        **void QTableWidget::setRowCount(int rows )**

        Sets the number of rows in this table's model to **rows**. If this is
        less than **rowCount** (), the data in the unwanted rows is discarded.

        **Note:** Setter function for property **rowCount** .

        **See also** **rowCount** () and **setColumnCount** ().
        """
        ...

    @property
    def cellActivated(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#cellActivated

        **[signal] void QTableWidget::cellActivated(int row , int column )**

        This signal is emitted when the cell specified by **row** and **column**
        has been activated
        """
        ...

    @property
    def cellChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#cellChanged

        **[signal] void QTableWidget::cellChanged(int row , int column )**

        This signal is emitted whenever the data of the item in the cell
        specified by **row** and **column** has changed.
        """
        ...

    @property
    def cellClicked(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#cellClicked

        **[signal] void QTableWidget::cellClicked(int row , int column )**

        This signal is emitted whenever a cell in the table is clicked. The
        **row** and **column** specified is the cell that was clicked.
        """
        ...

    @property
    def cellDoubleClicked(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#cellDoubleClicked

        **[signal] void QTableWidget::cellDoubleClicked(int row , int column )**

        This signal is emitted whenever a cell in the table is double clicked.
        The **row** and **column** specified is the cell that was double
        clicked.
        """
        ...

    @property
    def cellEntered(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#cellEntered

        **[signal] void QTableWidget::cellEntered(int row , int column )**

        This signal is emitted when the mouse cursor enters a cell. The cell is
        specified by **row** and **column**.

        This signal is only emitted when mouseTracking is turned on, or when a
        mouse button is pressed while moving into an item.
        """
        ...

    @property
    def cellPressed(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#cellPressed

        **[signal] void QTableWidget::cellPressed(int row , int column )**

        This signal is emitted whenever a cell in the table is pressed. The
        **row** and **column** specified is the cell that was pressed.
        """
        ...

    @property
    def currentCellChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#currentCellChanged

        **[signal] void QTableWidget::currentCellChanged(int currentRow , int
        currentColumn , int previousRow , int previousColumn )**

        This signal is emitted whenever the current cell changes. The cell
        specified by **previousRow** and **previousColumn** is the cell that
        previously had the focus, the cell specified by **currentRow** and
        **currentColumn** is the new current cell.
        """
        ...

    @property
    def currentItemChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#currentItemChanged

        **[signal] void QTableWidget::currentItemChanged(QTableWidgetItem *
        current , QTableWidgetItem * previous )**

        This signal is emitted whenever the current item changes. The
        **previous** item is the item that previously had the focus, **current**
        is the new current item.
        """
        ...

    @property
    def itemActivated(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#itemActivated

        **[signal] void QTableWidget::itemActivated(QTableWidgetItem * item )**

        This signal is emitted when the specified **item** has been activated
        """
        ...

    @property
    def itemChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#itemChanged

        **[signal] void QTableWidget::itemChanged(QTableWidgetItem * item )**

        This signal is emitted whenever the data of **item** has changed.
        """
        ...

    @property
    def itemClicked(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#itemClicked

        **[signal] void QTableWidget::itemClicked(QTableWidgetItem * item )**

        This signal is emitted whenever an item in the table is clicked. The
        **item** specified is the item that was clicked.
        """
        ...

    @property
    def itemDoubleClicked(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#itemDoubleClicked

        **[signal] void QTableWidget::itemDoubleClicked(QTableWidgetItem * item
        )**

        This signal is emitted whenever an item in the table is double clicked.
        The **item** specified is the item that was double clicked.
        """
        ...

    @property
    def itemEntered(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#itemEntered

        **[signal] void QTableWidget::itemEntered(QTableWidgetItem * item )**

        This signal is emitted when the mouse cursor enters an item. The
        **item** is the item entered.

        This signal is only emitted when mouseTracking is turned on, or when a
        mouse button is pressed while moving into an item.
        """
        ...

    @property
    def itemPressed(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#itemPressed

        **[signal] void QTableWidget::itemPressed(QTableWidgetItem * item )**

        This signal is emitted whenever an item in the table is pressed. The
        **item** specified is the item that was pressed.
        """
        ...

    @property
    def itemSelectionChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtablewidget.html#itemSelectionChanged

        **[signal] void QTableWidget::itemSelectionChanged()**

        This signal is emitted whenever the selection changes.

        **See also** **selectedItems** () and **QTableWidgetItem::isSelected**
        ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QRect(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qrect.html

    **Detailed Description**

    A rectangle is normally expressed as a top-left corner and a size. The size
    (width and height) of a QRect is always equivalent to the mathematical
    rectangle that forms the basis for its rendering.

    A QRect can be constructed with a set of left, top, width and height
    integers, or from a **QPoint**  and a **QSize** . The following code creates
    two identical rectangles.

    **QRect**  r1(100, 200, 11, 16);
        **QRect**  r2(**QPoint** (100, 200),
    **QSize** (11, 16));

    There is a third constructor that creates a QRect using the top-left and
    bottom-right coordinates, but we recommend that you avoid using it. The
    rationale is that for historical reasons the values returned by the
    **bottom** () and **right** () functions deviate from the true bottom-right
    corner of the rectangle.

    The QRect class provides a collection of functions that return the various
    rectangle coordinates, and enable manipulation of these. QRect also provides
    functions to move the rectangle relative to the various coordinates. In
    addition there is a **moveTo** () function that moves the rectangle, leaving
    its top left corner at the given coordinates. Alternatively, the
    **translate** () function moves the rectangle the given offset relative to
    the current position, and the **translated** () function returns a
    translated copy of this rectangle.

    The **size** () function returns the rectangle's dimensions as a **QSize** .
    The dimensions can also be retrieved separately using the **width** () and
    **height** () functions. To manipulate the dimensions use the **setSize**
    (), **setWidth** () or **setHeight** () functions. Alternatively, the size
    can be changed by applying either of the functions setting the rectangle
    coordinates, for example, **setBottom** () or **setRight** ().

    The **contains** () function tells whether a given point is inside the
    rectangle or not, and the **intersects** () function returns `true` if this
    rectangle intersects with a given rectangle. The QRect class also provides
    the **intersected** () function which returns the intersection rectangle,
    and the **united** () function which returns the rectangle that encloses the
    given rectangle and this:

    ![](images/qrect-intersect.png)![](images/qrect-unite.png)
    **intersected**
    ()**united** ()

    The **isEmpty** () function returns `true` if **left** () > **right** () or
    **top** () > **bottom** (). Note that an empty rectangle is not valid: The
    **isValid** () function returns `true` if **left** () <= **right** ()
    **and** **top** () <= **bottom** (). A null rectangle (**isNull** () ==
    true) on the other hand, has both width and height set to 0.

    Note that due to the way QRect and **QRectF**  are defined, an empty QRect
    is defined in essentially the same way as **QRectF** .

    Finally, QRect objects can be streamed as well as compared.

    **Rendering**

    When using an **anti-aliased**  painter, the boundary line of a QRect will
    be rendered symmetrically on both sides of the mathematical rectangle's
    boundary line. But when using an aliased painter (the default) other rules
    apply.

    Then, when rendering with a one pixel wide pen the QRect's boundary line
    will be rendered to the right and below the mathematical rectangle's
    boundary line.

    When rendering with a two pixels wide pen the boundary line will be split in
    the middle by the mathematical rectangle. This will be the case whenever the
    pen is set to an even number of pixels, while rendering with a pen with an
    odd number of pixels, the spare pixel will be rendered to the right and
    below the mathematical rectangle as in the one pixel case.

    ![](images/qrect-diagram-zero.png)![](images/qrect-diagram-one.png)
    Logical representationOne pixel wide pen
    ![](images/qrect-diagram-
    two.png)![](images/qrect-diagram-three.png)
    Two pixel wide penThree pixel
    wide pen

    **Coordinates**

    The QRect class provides a collection of functions that return the various
    rectangle coordinates, and enable manipulation of these. QRect also provides
    functions to move the rectangle relative to the various coordinates.

    For example the **left** (), **setLeft** () and **moveLeft** () functions as
    an example: **left** () returns the x-coordinate of the rectangle's left
    edge, **setLeft** () sets the left edge of the rectangle to the given x
    coordinate (it may change the width, but will never change the rectangle's
    right edge) and **moveLeft** () moves the entire rectangle horizontally,
    leaving the rectangle's left edge at the given x coordinate and its size
    unchanged.

    ![](images/qrect-coordinates.png)

    Note that for historical reasons the values returned by the **bottom** ()
    and **right** () functions deviate from the true bottom-right corner of the
    rectangle: The **right** () function returns ****left** () + **width** () -
    1** and the **bottom** () function returns ****top** () + **height** () -
    1**. The same is the case for the point returned by the **bottomRight** ()
    convenience function. In addition, the x and y coordinate of the
    **topRight** () and **bottomLeft** () functions, respectively, contain the
    same deviation from the true right and bottom edges.

    We recommend that you use **x** () + **width** () and **y** () + **height**
    () to find the true bottom-right corner, and avoid **right** () and
    **bottom** (). Another solution is to use **QRectF** : The **QRectF**  class
    defines a rectangle in the plane using floating point accuracy for
    coordinates, and the **QRectF::right** () and **QRectF::bottom** ()
    functions **do** return the right and bottom coordinates.

    It is also possible to add offsets to this rectangle's coordinates using the
    **adjust** () function, as well as retrieve a new rectangle based on
    adjustments of the original one using the **adjusted** () function. If
    either of the width and height is negative, use the **normalized** ()
    function to retrieve a rectangle where the corners are swapped.

    In addition, QRect provides the **getCoords** () function which extracts the
    position of the rectangle's top-left and bottom-right corner, and the
    **getRect** () function which extracts the rectangle's top-left corner,
    width and height. Use the **setCoords** () and **setRect** () function to
    manipulate the rectangle's coordinates and dimensions in one go.

    **Constraints**

    QRect is limited to the minimum and maximum values for the `int` type.
    Operations on a QRect that could potentially result in values outside this
    range will result in undefined behavior.

    **See also** **QRectF**  and **QRegion** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qrect.html#QRect

        **QRect::QRect()**

        Constructs a null rectangle.

        **See also** **isNull** ().
        """
        ...

    @typing.overload
    def __init__(self, aleft: int, atop: int, awidth: int, aheight: int) -> None:
        """
        https://doc.qt.io/qt-6/qrect.html#QRect-1

        **QRect::QRect(const QPoint & topLeft , const QPoint & bottomRight )**

        Constructs a rectangle with the given **topLeft** and **bottomRight**
        corners, both included.

        If **bottomRight** is to higher and to the left of **topLeft** , the
        rectangle defined is instead non-inclusive of the corners.

        **Note:** To ensure both points are included regardless of relative
        order, use **span** ().

        **See also** **setTopLeft** (), **setBottomRight** (), and **span** ().
        """
        ...

    @typing.overload
    def __init__(self, atopLeft: QPoint, abottomRight: QPoint) -> None:
        """
        https://doc.qt.io/qt-6/qrect.html#QRect-2

        **QRect::QRect(const QPoint & topLeft , const QSize & size )**

        Constructs a rectangle with the given **topLeft** corner and the given
        **size**.

        **See also** **setTopLeft** () and **setSize** ().
        """
        ...

    @typing.overload
    def __init__(self, atopLeft: QPoint, asize: "QSize") -> None:
        """
        https://doc.qt.io/qt-6/qrect.html#QRect-3

        **QRect::QRect(int x , int y , int width , int height )**

        Constructs a rectangle with ( **x** , **y** ) as its top-left corner and
        the given **width** and **height**.

        **See also** **setRect** ().
        """
        ...

    @typing.overload
    def __init__(self, a0: "QRect") -> None:
        """
        https://doc.qt.io/qt-6/qrect.html#QRect

        **QRect::QRect()**

        Constructs a null rectangle.

        **See also** **isNull** ().
        """
        ...

    @staticmethod
    def span(p1: QPoint, p2: QPoint) -> "QRect":
        """
        https://doc.qt.io/qt-6/qrect.html#span

        **[static, since 6.0] QRect QRect::span(const QPoint & p1 , const QPoint
        & p2 )**

        Returns a rectangle spanning the two points **p1** and **p2** ,
        including both and everything in between.

        This function was introduced in Qt 6.0.
        """
        ...

    def transposed(self) -> "QRect":
        """
        https://doc.qt.io/qt-6/qrect.html#transposed

        **[since 5.7] QRect QRect::transposed() const**

        Returns a copy of the rectangle that has its width and height exchanged:

        **QRect**  r = {15, 51, 42, 24};
            r = r.transposed(); // r == {15,
        51, 24, 42}

        This function was introduced in Qt 5.7.

        **See also** **QSize::transposed** ().
        """
        ...

    def marginsRemoved(self, margins: QMargins) -> "QRect":
        """
        https://doc.qt.io/qt-6/qrect.html#marginsRemoved

        **[since 5.1] QRect QRect::marginsRemoved(const QMargins & margins )
        const**

        Removes the **margins** from the rectangle, shrinking it.

        This function was introduced in Qt 5.1.

        **See also** **marginsAdded** (), **operator+=** (), and **operator-=**
        ().
        """
        ...

    def marginsAdded(self, margins: QMargins) -> "QRect":
        """
        https://doc.qt.io/qt-6/qrect.html#marginsAdded

        **[since 5.1] QRect QRect::marginsAdded(const QMargins & margins )
        const**

        Returns a rectangle grown by the **margins**.

        This function was introduced in Qt 5.1.

        **See also** **operator+=** (), **marginsRemoved** (), and
        **operator-=** ().
        """
        ...

    def united(self, r: "QRect") -> "QRect":
        """
        https://doc.qt.io/qt-6/qrect.html#united

        **QRect QRect::united(const QRect & rectangle ) const**

        Returns the bounding rectangle of this rectangle and the given
        **rectangle**.

        ![](images/qrect-unite.png)

        **See also** **intersected** ().
        """
        ...

    def intersected(self, other: "QRect") -> "QRect":
        """
        https://doc.qt.io/qt-6/qrect.html#intersected

        **QRect QRect::intersected(const QRect & rectangle ) const**

        Returns the intersection of this rectangle and the given **rectangle**.
        Note that `r.intersected(s)` is equivalent to `r & s`.

        ![](images/qrect-intersect.png)

        **See also** **intersects** (), **united** (), and **operator&=** ().
        """
        ...

    def setSize(self, s: "QSize") -> None:
        """
        https://doc.qt.io/qt-6/qrect.html#setSize

        **void QRect::setSize(const QSize & size )**

        Sets the size of the rectangle to the given **size**. The top-left
        corner is not moved.

        **See also** **size** (), **setWidth** (), and **setHeight** ().
        """
        ...

    def setHeight(self, h: int) -> None:
        """
        https://doc.qt.io/qt-6/qrect.html#setHeight

        **void QRect::setHeight(int height )**

        Sets the height of the rectangle to the given **height**. The bottom
        edge is changed, but not the top one.

        **See also** **height** () and **setSize** ().
        """
        ...

    def setWidth(self, w: int) -> None:
        """
        https://doc.qt.io/qt-6/qrect.html#setWidth

        **void QRect::setWidth(int width )**

        Sets the width of the rectangle to the given **width**. The right edge
        is changed, but not the left one.

        **See also** **width** () and **setSize** ().
        """
        ...

    def adjust(self, dx1: int, dy1: int, dx2: int, dy2: int) -> None:
        """
        https://doc.qt.io/qt-6/qrect.html#adjust

        **void QRect::adjust(int dx1 , int dy1 , int dx2 , int dy2 )**

        Adds **dx1** , **dy1** , **dx2** and **dy2** respectively to the
        existing coordinates of the rectangle.

        **See also** **adjusted** () and **setRect** ().
        """
        ...

    def adjusted(self, xp1: int, yp1: int, xp2: int, yp2: int) -> "QRect":
        """
        https://doc.qt.io/qt-6/qrect.html#adjusted

        **QRect QRect::adjusted(int dx1 , int dy1 , int dx2 , int dy2 ) const**

        Returns a new rectangle with **dx1** , **dy1** , **dx2** and **dy2**
        added respectively to the existing coordinates of this rectangle.

        **See also** **adjust** ().
        """
        ...

    def setCoords(self, xp1: int, yp1: int, xp2: int, yp2: int) -> None:
        """
        https://doc.qt.io/qt-6/qrect.html#setCoords

        **void QRect::setCoords(int x1 , int y1 , int x2 , int y2 )**

        Sets the coordinates of the rectangle's top-left corner to ( **x1** ,
        **y1** ), and the coordinates of its bottom-right corner to ( **x2** ,
        **y2** ).

        **See also** **getCoords** () and **setRect** ().
        """
        ...

    def getCoords(self) -> typing.Tuple[int, int, int, int]:
        """
        https://doc.qt.io/qt-6/qrect.html#getCoords

        **void QRect::getCoords(int * x1 , int * y1 , int * x2 , int * y2 )
        const**

        Extracts the position of the rectangle's top-left corner to * **x1** and
        * **y1** , and the position of the bottom-right corner to * **x2** and *
        **y2**.

        **See also** **setCoords** () and **getRect** ().
        """
        ...

    def setRect(self, ax: int, ay: int, aw: int, ah: int) -> None:
        """
        https://doc.qt.io/qt-6/qrect.html#setRect

        **void QRect::setRect(int x , int y , int width , int height )**

        Sets the coordinates of the rectangle's top-left corner to ( **x** ,
        **y** ), and its size to the given **width** and **height**.

        **See also** **getRect** () and **setCoords** ().
        """
        ...

    def getRect(self) -> typing.Tuple[int, int, int, int]:
        """
        https://doc.qt.io/qt-6/qrect.html#getRect

        **void QRect::getRect(int * x , int * y , int * width , int * height )
        const**

        Extracts the position of the rectangle's top-left corner to * **x** and
        * **y** , and its dimensions to * **width** and * **height**.

        **See also** **setRect** () and **getCoords** ().
        """
        ...

    def moveBottomLeft(self, p: QPoint) -> None:
        """
        https://doc.qt.io/qt-6/qrect.html#moveBottomLeft

        **void QRect::moveBottomLeft(const QPoint & position )**

        Moves the rectangle, leaving the bottom-left corner at the given
        **position**. The rectangle's size is unchanged.

        **See also** **setBottomLeft** (), **moveBottom** (), and **moveLeft**
        ().
        """
        ...

    def moveTopRight(self, p: QPoint) -> None:
        """
        https://doc.qt.io/qt-6/qrect.html#moveTopRight

        **void QRect::moveTopRight(const QPoint & position )**

        Moves the rectangle, leaving the top-right corner at the given
        **position**. The rectangle's size is unchanged.

        **See also** **setTopRight** (), **moveTop** (), and **moveRight** ().
        """
        ...

    def moveBottomRight(self, p: QPoint) -> None:
        """
        https://doc.qt.io/qt-6/qrect.html#moveBottomRight

        **void QRect::moveBottomRight(const QPoint & position )**

        Moves the rectangle, leaving the bottom-right corner at the given
        **position**. The rectangle's size is unchanged.

        **See also** **setBottomRight** (), **moveRight** (), and **moveBottom**
        ().
        """
        ...

    def moveTopLeft(self, p: QPoint) -> None:
        """
        https://doc.qt.io/qt-6/qrect.html#moveTopLeft

        **void QRect::moveTopLeft(const QPoint & position )**

        Moves the rectangle, leaving the top-left corner at the given
        **position**. The rectangle's size is unchanged.

        **See also** **setTopLeft** (), **moveTop** (), and **moveLeft** ().
        """
        ...

    def moveBottom(self, pos: int) -> None:
        """
        https://doc.qt.io/qt-6/qrect.html#moveBottom

        **void QRect::moveBottom(int y )**

        Moves the rectangle vertically, leaving the rectangle's bottom edge at
        the given **y** coordinate. The rectangle's size is unchanged.

        **See also** **bottom** (), **setBottom** (), and **moveTop** ().
        """
        ...

    def moveRight(self, pos: int) -> None:
        """
        https://doc.qt.io/qt-6/qrect.html#moveRight

        **void QRect::moveRight(int x )**

        Moves the rectangle horizontally, leaving the rectangle's right edge at
        the given **x** coordinate. The rectangle's size is unchanged.

        **See also** **right** (), **setRight** (), and **moveLeft** ().
        """
        ...

    def moveTop(self, pos: int) -> None:
        """
        https://doc.qt.io/qt-6/qrect.html#moveTop

        **void QRect::moveTop(int y )**

        Moves the rectangle vertically, leaving the rectangle's top edge at the
        given **y** coordinate. The rectangle's size is unchanged.

        **See also** **top** (), **setTop** (), and **moveBottom** ().
        """
        ...

    def moveLeft(self, pos: int) -> None:
        """
        https://doc.qt.io/qt-6/qrect.html#moveLeft

        **void QRect::moveLeft(int x )**

        Moves the rectangle horizontally, leaving the rectangle's left edge at
        the given **x** coordinate. The rectangle's size is unchanged.

        **See also** **left** (), **setLeft** (), and **moveRight** ().
        """
        ...

    @typing.overload
    def moveTo(self, ax: int, ay: int) -> None:
        """
        https://doc.qt.io/qt-6/qrect.html#moveTo

        **void QRect::moveTo(int x , int y )**

        Moves the rectangle, leaving the top-left corner at the given position (
        **x** , **y** ). The rectangle's size is unchanged.

        **See also** **translate** () and **moveTopLeft** ().
        """
        ...

    @typing.overload
    def moveTo(self, p: QPoint) -> None:
        """
        https://doc.qt.io/qt-6/qrect.html#moveTo-1

        **void QRect::moveTo(const QPoint & position )**

        Moves the rectangle, leaving the top-left corner at the given
        **position**.
        """
        ...

    @typing.overload
    def translated(self, dx: int, dy: int) -> "QRect":
        """
        https://doc.qt.io/qt-6/qrect.html#translated

        **QRect QRect::translated(int dx , int dy ) const**

        Returns a copy of the rectangle that is translated **dx** along the x
        axis and **dy** along the y axis, relative to the current position.
        Positive values move the rectangle to the right and down.

        **See also** **translate** ().
        """
        ...

    @typing.overload
    def translated(self, p: QPoint) -> "QRect":
        """
        https://doc.qt.io/qt-6/qrect.html#translated-1

        **QRect QRect::translated(const QPoint & offset ) const**

        This is an overloaded function.

        Returns a copy of the rectangle that is translated **offset**.**x** ()
        along the x axis and **offset**.**y** () along the y axis, relative to
        the current position.
        """
        ...

    @typing.overload
    def translate(self, dx: int, dy: int) -> None:
        """
        https://doc.qt.io/qt-6/qrect.html#translate

        **void QRect::translate(int dx , int dy )**

        Moves the rectangle **dx** along the x axis and **dy** along the y axis,
        relative to the current position. Positive values move the rectangle to
        the right and down.

        **See also** **moveTopLeft** (), **moveTo** (), and **translated** ().
        """
        ...

    @typing.overload
    def translate(self, p: QPoint) -> None:
        """
        https://doc.qt.io/qt-6/qrect.html#translate-1

        **void QRect::translate(const QPoint & offset )**

        This is an overloaded function.

        Moves the rectangle **offset**.**x** () along the x axis and
        **offset**.**y** () along the y axis, relative to the current position.
        """
        ...

    def size(self) -> "QSize":
        """
        https://doc.qt.io/qt-6/qrect.html#size

        **QSize QRect::size() const**

        Returns the size of the rectangle.

        **See also** **setSize** (), **width** (), and **height** ().
        """
        ...

    def height(self) -> int:
        """
        https://doc.qt.io/qt-6/qrect.html#height

        **int QRect::height() const**

        Returns the height of the rectangle.

        **See also** **setHeight** (), **width** (), and **size** ().
        """
        ...

    def width(self) -> int:
        """
        https://doc.qt.io/qt-6/qrect.html#width

        **int QRect::width() const**

        Returns the width of the rectangle.

        **See also** **setWidth** (), **height** (), and **size** ().
        """
        ...

    def center(self) -> QPoint:
        """
        https://doc.qt.io/qt-6/qrect.html#center

        **QPoint QRect::center() const**

        Returns the center point of the rectangle.

        **See also** **moveCenter** ().
        """
        ...

    def bottomLeft(self) -> QPoint:
        """
        https://doc.qt.io/qt-6/qrect.html#bottomLeft

        **QPoint QRect::bottomLeft() const**

        Returns the position of the rectangle's bottom-left corner. Note that
        for historical reasons this function returns **QPoint** (**left** (),
        **top** () + **height** () - 1).

        **See also** **setBottomLeft** (), **bottom** (), and **left** ().
        """
        ...

    def topRight(self) -> QPoint:
        """
        https://doc.qt.io/qt-6/qrect.html#topRight

        **QPoint QRect::topRight() const**

        Returns the position of the rectangle's top-right corner.

        Note that for historical reasons this function returns **QPoint**
        (**left** () + **width** () -1, **top** ()).

        **See also** **setTopRight** (), **top** (), and **right** ().
        """
        ...

    def bottomRight(self) -> QPoint:
        """
        https://doc.qt.io/qt-6/qrect.html#bottomRight

        **QPoint QRect::bottomRight() const**

        Returns the position of the rectangle's bottom-right corner.

        Note that for historical reasons this function returns **QPoint**
        (**left** () + **width** () -1, **top** () + **height** () - 1).

        **See also** **setBottomRight** (), **bottom** (), and **right** ().
        """
        ...

    def topLeft(self) -> QPoint:
        """
        https://doc.qt.io/qt-6/qrect.html#topLeft

        **QPoint QRect::topLeft() const**

        Returns the position of the rectangle's top-left corner.

        **See also** **setTopLeft** (), **top** (), and **left** ().
        """
        ...

    def setY(self, ay: int) -> None:
        """
        https://doc.qt.io/qt-6/qrect.html#setY

        **void QRect::setY(int y )**

        Sets the top edge of the rectangle to the given **y** coordinate. May
        change the height, but will never change the bottom edge of the
        rectangle.

        Equivalent to **setTop** ().

        **See also** **y** (), **setX** (), and **setTopLeft** ().
        """
        ...

    def setX(self, ax: int) -> None:
        """
        https://doc.qt.io/qt-6/qrect.html#setX

        **void QRect::setX(int x )**

        Sets the left edge of the rectangle to the given **x** coordinate. May
        change the width, but will never change the right edge of the rectangle.

        Equivalent to **setLeft** ().

        **See also** **x** (), **setY** (), and **setTopLeft** ().
        """
        ...

    def setBottomLeft(self, p: QPoint) -> None:
        """
        https://doc.qt.io/qt-6/qrect.html#setBottomLeft

        **void QRect::setBottomLeft(const QPoint & position )**

        Set the bottom-left corner of the rectangle to the given **position**.
        May change the size, but will never change the top-right corner of the
        rectangle.

        **See also** **bottomLeft** () and **moveBottomLeft** ().
        """
        ...

    def setTopRight(self, p: QPoint) -> None:
        """
        https://doc.qt.io/qt-6/qrect.html#setTopRight

        **void QRect::setTopRight(const QPoint & position )**

        Set the top-right corner of the rectangle to the given **position**. May
        change the size, but will never change the bottom-left corner of the
        rectangle.

        **See also** **topRight** () and **moveTopRight** ().
        """
        ...

    def setBottomRight(self, p: QPoint) -> None:
        """
        https://doc.qt.io/qt-6/qrect.html#setBottomRight

        **void QRect::setBottomRight(const QPoint & position )**

        Set the bottom-right corner of the rectangle to the given **position**.
        May change the size, but will never change the top-left corner of the
        rectangle.

        **See also** **bottomRight** () and **moveBottomRight** ().
        """
        ...

    def setTopLeft(self, p: QPoint) -> None:
        """
        https://doc.qt.io/qt-6/qrect.html#setTopLeft

        **void QRect::setTopLeft(const QPoint & position )**

        Set the top-left corner of the rectangle to the given **position**. May
        change the size, but will never change the bottom-right corner of the
        rectangle.

        **See also** **topLeft** () and **moveTopLeft** ().
        """
        ...

    def setBottom(self, pos: int) -> None:
        """
        https://doc.qt.io/qt-6/qrect.html#setBottom

        **void QRect::setBottom(int y )**

        Sets the bottom edge of the rectangle to the given **y** coordinate. May
        change the height, but will never change the top edge of the rectangle.

        **See also** **bottom** () and **moveBottom** ().
        """
        ...

    def setRight(self, pos: int) -> None:
        """
        https://doc.qt.io/qt-6/qrect.html#setRight

        **void QRect::setRight(int x )**

        Sets the right edge of the rectangle to the given **x** coordinate. May
        change the width, but will never change the left edge of the rectangle.

        **See also** **right** () and **moveRight** ().
        """
        ...

    def setTop(self, pos: int) -> None:
        """
        https://doc.qt.io/qt-6/qrect.html#setTop

        **void QRect::setTop(int y )**

        Sets the top edge of the rectangle to the given **y** coordinate. May
        change the height, but will never change the bottom edge of the
        rectangle.

        Equivalent to **setY** ().

        **See also** **top** () and **moveTop** ().
        """
        ...

    def setLeft(self, pos: int) -> None:
        """
        https://doc.qt.io/qt-6/qrect.html#setLeft

        **void QRect::setLeft(int x )**

        Sets the left edge of the rectangle to the given **x** coordinate. May
        change the width, but will never change the right edge of the rectangle.

        Equivalent to **setX** ().

        **See also** **left** () and **moveLeft** ().
        """
        ...

    def y(self) -> int:
        """
        https://doc.qt.io/qt-6/qrect.html#y

        **int QRect::y() const**

        Returns the y-coordinate of the rectangle's top edge. Equivalent to
        **top** ().

        **See also** **setY** (), **x** (), and **topLeft** ().
        """
        ...

    def x(self) -> int:
        """
        https://doc.qt.io/qt-6/qrect.html#x

        **int QRect::x() const**

        Returns the x-coordinate of the rectangle's left edge. Equivalent to
        **left** ().

        **See also** **setX** (), **y** (), and **topLeft** ().
        """
        ...

    def bottom(self) -> int:
        """
        https://doc.qt.io/qt-6/qrect.html#bottom

        **int QRect::bottom() const**

        Returns the y-coordinate of the rectangle's bottom edge.

        Note that for historical reasons this function returns **top** () +
        **height** () - 1; use **y** () + **height** () to retrieve the true
        y-coordinate.

        **See also** **setBottom** (), **bottomLeft** (), and **bottomRight**
        ().
        """
        ...

    def right(self) -> int:
        """
        https://doc.qt.io/qt-6/qrect.html#right

        **int QRect::right() const**

        Returns the x-coordinate of the rectangle's right edge.

        Note that for historical reasons this function returns **left** () +
        **width** () - 1; use **x** () + **width** () to retrieve the true
        x-coordinate.

        **See also** **setRight** (), **topRight** (), and **bottomRight** ().
        """
        ...

    def top(self) -> int:
        """
        https://doc.qt.io/qt-6/qrect.html#top

        **int QRect::top() const**

        Returns the y-coordinate of the rectangle's top edge. Equivalent to
        **y** ().

        **See also** **setTop** (), **topLeft** (), and **topRight** ().
        """
        ...

    def left(self) -> int:
        """
        https://doc.qt.io/qt-6/qrect.html#left

        **int QRect::left() const**

        Returns the x-coordinate of the rectangle's left edge. Equivalent to
        **x** ().

        **See also** **setLeft** (), **topLeft** (), and **bottomLeft** ().
        """
        ...

    def __hash__(self) -> int:
        ...

    def __bool__(self) -> int:
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qrect.html#isValid

        **bool QRect::isValid() const**

        Returns `true` if the rectangle is valid, otherwise returns `false`.

        A valid rectangle has a **left** () <= **right** () and **top** () <=
        **bottom** (). Note that non-trivial operations like intersections are
        not defined for invalid rectangles. A valid rectangle is not empty
        (i.e., isValid() == !**isEmpty** ()).

        **See also** **isNull** (), **isEmpty** (), and **normalized** ().
        """
        ...

    def isEmpty(self) -> bool:
        """
        https://doc.qt.io/qt-6/qrect.html#isEmpty

        **bool QRect::isEmpty() const**

        Returns `true` if the rectangle is empty, otherwise returns `false`.

        An empty rectangle has a **left** () > **right** () or **top** () >
        **bottom** (). An empty rectangle is not valid (i.e., isEmpty() ==
        !**isValid** ()).

        Use the **normalized** () function to retrieve a rectangle where the
        corners are swapped.

        **See also** **isNull** (), **isValid** (), and **normalized** ().
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qrect.html#isNull

        **bool QRect::isNull() const**

        Returns `true` if the rectangle is a null rectangle, otherwise returns
        `false`.

        A null rectangle has both the width and the height set to 0 (i.e.,
        **right** () == **left** () - 1 and **bottom** () == **top** () - 1). A
        null rectangle is also empty, and hence is not valid.

        **See also** **isEmpty** () and **isValid** ().
        """
        ...

    def __repr__(self) -> str:
        ...

    def intersects(self, r: "QRect") -> bool:
        """
        https://doc.qt.io/qt-6/qrect.html#intersects

        **bool QRect::intersects(const QRect & rectangle ) const**

        Returns `true` if this rectangle intersects with the given **rectangle**
        (i.e., there is at least one pixel that is within both rectangles),
        otherwise returns `false`.

        The intersection rectangle can be retrieved using the **intersected** ()
        function.

        **See also** **contains** ().
        """
        ...

    @typing.overload
    def __contains__(self, p: QPoint) -> int:
        ...

    @typing.overload
    def __contains__(self, r: "QRect") -> int:
        ...

    @typing.overload
    def contains(self, point: QPoint, proper: bool = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qrect.html#contains

        **bool QRect::contains(const QPoint & point , bool proper = false)
        const**

        Returns `true` if the given **point** is inside or on the edge of the
        rectangle, otherwise returns `false`. If **proper** is true, this
        function only returns `true` if the given **point** is **inside** the
        rectangle (i.e., not on the edge).

        **See also** **intersects** ().
        """
        ...

    @typing.overload
    def contains(self, rectangle: "QRect", proper: bool = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qrect.html#contains-1

        **bool QRect::contains(const QRect & rectangle , bool proper = false)
        const**

        This is an overloaded function.

        Returns `true` if the given **rectangle** is inside this rectangle.
        otherwise returns `false`. If **proper** is true, this function only
        returns `true` if the **rectangle** is entirely inside this rectangle
        (not on the edge).
        """
        ...

    @typing.overload
    def contains(self, ax: int, ay: int, aproper: bool) -> bool:
        """
        https://doc.qt.io/qt-6/qrect.html#contains-2

        **bool QRect::contains(int x , int y ) const**

        This is an overloaded function.

        Returns `true` if the point ( **x** , **y** ) is inside this rectangle,
        otherwise returns `false`.
        """
        ...

    @typing.overload
    def contains(self, ax: int, ay: int) -> bool:
        """
        https://doc.qt.io/qt-6/qrect.html#contains-3

        **bool QRect::contains(int x , int y , bool proper ) const**

        This is an overloaded function.

        Returns `true` if the point ( **x** , **y** ) is inside or on the edge
        of the rectangle, otherwise returns `false`. If **proper** is true, this
        function only returns `true` if the point is entirely inside the
        rectangle(not on the edge).
        """
        ...

    def moveCenter(self, p: QPoint) -> None:
        """
        https://doc.qt.io/qt-6/qrect.html#moveCenter

        **void QRect::moveCenter(const QPoint & position )**

        Moves the rectangle, leaving the center point at the given **position**.
        The rectangle's size is unchanged.

        **See also** **center** ().
        """
        ...

    def normalized(self) -> "QRect":
        """
        https://doc.qt.io/qt-6/qrect.html#normalized

        **QRect QRect::normalized() const**

        Returns a normalized rectangle; i.e., a rectangle that has a non-
        negative width and height.

        If **width** () < 0 the function swaps the left and right corners, and
        it swaps the top and bottom corners if **height** () < 0\\. The corners
        are at the same time changed from being non-inclusive to inclusive.

        **See also** **isValid** () and **isEmpty** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QGraphicsSceneResizeEvent(QGraphicsSceneEvent):
    """
    https://doc.qt.io/qt-6/qgraphicssceneresizeevent.html

    **Detailed Description**

    A **QGraphicsWidget**  sends itself a QGraphicsSceneResizeEvent immediately
    when its geometry changes.

    It's similar to **QResizeEvent** , but its sizes, **oldSize** () and
    **newSize** (), use **QSizeF**  instead of **QSize** .

    **See also** **QGraphicsWidget::setGeometry** () and
    **QGraphicsWidget::resize** ().
    """

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicssceneresizeevent.html#QGraphicsSceneResi
        zeEvent-1

        **QGraphicsSceneResizeEvent::QGraphicsSceneResizeEvent()**

        Constructs a QGraphicsSceneResizeEvent.
        """
        ...

    def newSize(self) -> QtCore.QSizeF:
        """
        https://doc.qt.io/qt-6/qgraphicssceneresizeevent.html#newSize

        **QSizeF QGraphicsSceneResizeEvent::newSize() const**

        Returns the new size (i.e., the current size).

        **See also** **oldSize** () and **QGraphicsWidget::resize** ().
        """
        ...

    def oldSize(self) -> QtCore.QSizeF:
        """
        https://doc.qt.io/qt-6/qgraphicssceneresizeevent.html#oldSize

        **QSizeF QGraphicsSceneResizeEvent::oldSize() const**

        Returns the old size (i.e., the size immediately before the widget was
        resized).

        **See also** **newSize** () and **QGraphicsWidget::resize** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QPlatformSurfaceEvent(QtCore.QEvent):
    """
    https://doc.qt.io/qt-6/qplatformsurfaceevent.html

    **Detailed Description**

    Platform window events are synchronously sent to windows and offscreen
    surfaces when their underlying native surfaces are created or are about to
    be destroyed.

    Applications can respond to these events to know when the underlying
    platform surface exists.
    """

    class SurfaceEventType(enum.Enum):
        SurfaceCreated: QPlatformSurfaceEvent = ...
        SurfaceAboutToBeDestroyed: QPlatformSurfaceEvent = ...

    def __init__(
        self, surfaceEventType: "QPlatformSurfaceEvent.SurfaceEventType"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qplatformsurfaceevent.html#QPlatformSurfaceEvent-
        2

        **QPlatformSurfaceEvent::QPlatformSurfaceEvent(QPlatformSurfaceEvent::Su
        rfaceEventType surfaceEventType )**

        Constructs a platform surface event for the given **surfaceEventType**.
        """
        ...

    def clone(self) -> "QPlatformSurfaceEvent":
        ...

    def surfaceEventType(self) -> "QPlatformSurfaceEvent.SurfaceEventType":
        """
        https://doc.qt.io/qt-6/qplatformsurfaceevent.html#surfaceEventType

        **QPlatformSurfaceEvent::SurfaceEventType
        QPlatformSurfaceEvent::surfaceEventType() const**

        Returns the specific type of platform surface event.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtSensors import *


class QSensorFilter(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qsensorfilter.html

    **Detailed Description**

    Some sensors (eg. the accelerometer) are often accessed very frequently.
    This may be slowed down by the use of signals and slots. The QSensorFilter
    interface provides a more efficient way for the sensor to notify your class
    that the sensor has changed.

    Additionally, multiple filters can be added to a sensor. They are called in
    order and each filter has the option to modify the values in the reading or
    to suppress the reading altogether.

    Note that the values in the class returned by **QSensor::reading** () will
    not be updated until after the filters have been run.

    **See also** **filter** ().
    """

    @typing.overload
    def __init__(self) -> None:
        ...

    @typing.overload
    def __init__(self, a0: "QSensorFilter") -> None:
        ...

    def filter(self, reading: QSensorReading) -> bool:
        """
        https://doc.qt.io/qt-6/qsensorfilter.html#filter

        **[pure virtual] bool QSensorFilter::filter(QSensorReading * reading )**

        This function is called when the sensor **reading** changes.

        The filter can modify the reading.

        Returns true to allow the next filter to receive the value. If this is
        the last filter, returning true causes the signal to be emitted and the
        value is stored in the sensor.

        Returns false to drop the reading.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QRawFont(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qrawfont.html

    **Detailed Description**

    **Note:** QRawFont is a low level class. For most purposes **QFont**  is a
    more appropriate class.

    Most commonly, when presenting text in a user interface, the exact fonts
    used to render the characters is to some extent unknown. This can be the
    case for several reasons: For instance, the actual, physical fonts present
    on the target system could be unexpected to the developers, or the text
    could contain user selected styles, sizes or writing systems that are not
    supported by font chosen in the code.

    Therefore, Qt's **QFont**  class really represents a query for fonts. When
    text is interpreted, Qt will do its best to match the text to the query, but
    depending on the support, different fonts can be used behind the scenes.

    For most use cases, this is both expected and necessary, as it minimizes the
    possibility of text in the user interface being undisplayable. In some
    cases, however, more direct control over the process might be useful. It is
    for these use cases the QRawFont class exists.

    A QRawFont object represents a single, physical instance of a given font in
    a given pixel size. I.e. in the typical case it represents a set of TrueType
    or OpenType font tables and uses a user specified pixel size to convert
    metrics into logical pixel units. It can be used in combination with the
    **QGlyphRun**  class to draw specific glyph indexes at specific positions,
    and also have accessors to some relevant data in the physical font.

    QRawFont only provides support for the main font technologies: GDI and
    DirectWrite on Windows platforms, FreeType on Linux platforms and CoreText
    on macOS. For other font back-ends, the APIs will be disabled.

    QRawFont can be constructed in a number of ways:

    * It can be constructed by calling QTextLayout::glyphs() or
    QTextFragment::glyphs(). The returned QGlyphs objects will contain QRawFont
    objects which represent the actual fonts used to render each portion of the
    text.
      * It can be constructed by passing a **QFont**  object to
    **QRawFont::fromFont** (). The function will return a QRawFont object
    representing the font that will be selected as response to the **QFont**
    query and the selected writing system.
      * It can be constructed by passing
    a file name or **QByteArray**  directly to the QRawFont constructor, or by
    calling **loadFromFile** () or **loadFromData** (). In this case, the font
    will not be registered in **QFontDatabase** , and it will not be available
    as part of regular font selection.

    QRawFont is considered local to the thread in which it is constructed
    (either using a constructor, or by calling **loadFromData** () or
    **loadFromFile** ()). The QRawFont cannot be moved to a different thread,
    but will have to be recreated in the thread in question.

    **Note:** For the requirement of caching glyph indexes and font selections
    for static text to avoid reshaping and relayouting in the inner loop of an
    application, a better choice is the **QStaticText**  class, since it
    optimizes the memory cost of the cache and also provides the possibility of
    paint engine specific caches for an additional speed-up.
    """

    class LayoutFlag(enum.Flag):
        SeparateAdvances: QRawFont = ...
        KernedAdvances: QRawFont = ...
        UseDesignMetrics: QRawFont = ...

    class AntialiasingType(enum.Enum):
        PixelAntialiasing: QRawFont = ...
        SubPixelAntialiasing: QRawFont = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qrawfont.html#QRawFont

        **QRawFont::QRawFont()**

        Constructs an invalid QRawFont.
        """
        ...

    @typing.overload
    def __init__(
        self,
        fileName: str,
        pixelSize: float,
        hintingPreference: QFont.HintingPreference = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qrawfont.html#QRawFont-1

        **QRawFont::QRawFont(const QString & fileName , qreal pixelSize ,
        QFont::HintingPreference hintingPreference =
        QFont::PreferDefaultHinting)**

        Constructs a QRawFont representing the font contained in the file
        referenced by **fileName** for the size (in pixels) given by
        **pixelSize** , and using the hinting preference specified by
        **hintingPreference**.

        **Note:** The referenced file must contain a TrueType or OpenType font.
        """
        ...

    @typing.overload
    def __init__(
        self,
        fontData: QtCore.QByteArray,
        pixelSize: float,
        hintingPreference: QFont.HintingPreference = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qrawfont.html#QRawFont-2

        **QRawFont::QRawFont(const QByteArray & fontData , qreal pixelSize ,
        QFont::HintingPreference hintingPreference =
        QFont::PreferDefaultHinting)**

        Constructs a QRawFont representing the font contained in the supplied
        **fontData** for the size (in pixels) given by **pixelSize** , and using
        the hinting preference specified by **hintingPreference**.

        **Note:** The data must contain a TrueType or OpenType font.
        """
        ...

    @typing.overload
    def __init__(self, other: "QRawFont") -> None:
        """
        https://doc.qt.io/qt-6/qrawfont.html#QRawFont-3

        **QRawFont::QRawFont(const QRawFont & other )**

        Creates a QRawFont which is a copy of **other**.
        """
        ...

    def __hash__(self) -> int:
        ...

    def capHeight(self) -> float:
        """
        https://doc.qt.io/qt-6/qrawfont.html#capHeight

        **[since 5.8] qreal QRawFont::capHeight() const**

        Returns the cap height of this **QRawFont**  in pixel units.

        The cap height of a font is the height of a capital letter above the
        baseline. It specifically is the height of capital letters that are flat
        - such as H or I - as opposed to round letters such as O, or pointed
        letters like A, both of which may display overshoot.

        This function was introduced in Qt 5.8.

        **See also** **QFontMetricsF::capHeight** ().
        """
        ...

    def swap(self, other: "QRawFont") -> None:
        """
        https://doc.qt.io/qt-6/qrawfont.html#swap

        **[since 5.0] void QRawFont::swap(QRawFont & other )**

        Swaps this raw font with **other**. This function is very fast and never
        fails.

        This function was introduced in Qt 5.0.
        """
        ...

    def underlinePosition(self) -> float:
        """
        https://doc.qt.io/qt-6/qrawfont.html#underlinePosition

        **qreal QRawFont::underlinePosition() const**

        Returns the position from baseline for drawing underlines below the text
        rendered with this font.
        """
        ...

    def lineThickness(self) -> float:
        """
        https://doc.qt.io/qt-6/qrawfont.html#lineThickness

        **qreal QRawFont::lineThickness() const**

        Returns the thickness for drawing lines (underline, overline, etc.)
        along with text drawn in this font.
        """
        ...

    def boundingRect(self, glyphIndex: int) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qrawfont.html#boundingRect

        **[since 5.0] QRectF QRawFont::boundingRect(quint32 glyphIndex ) const**

        Returns the smallest rectangle containing the glyph with the given
        **glyphIndex**.

        This function was introduced in Qt 5.0.
        """
        ...

    @staticmethod
    def fromFont(
        font: QFont, writingSystem: QFontDatabase.WritingSystem = ...
    ) -> "QRawFont":
        """
        https://doc.qt.io/qt-6/qrawfont.html#fromFont

        **[static] QRawFont QRawFont::fromFont(const QFont & font ,
        QFontDatabase::WritingSystem writingSystem = QFontDatabase::Any)**

        Fetches the physical representation based on a **font** query. The
        physical font returned is the font that will be preferred by Qt in order
        to display text in the selected **writingSystem**.

        **Warning:** This function is potentially expensive and should not be
        called in performance sensitive code.
        """
        ...

    def fontTable(self, tagName: str) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qrawfont.html#fontTable

        **QByteArray QRawFont::fontTable(const char * tagName ) const**

        Retrieves the sfnt table named **tagName** from the underlying physical
        font, or an empty byte array if no such table was found. The returned
        font table's byte order is Big Endian, like the sfnt format specifies.
        The **tagName** must be four characters long and should be formatted in
        the default endianness of the current platform.
        """
        ...

    def supportedWritingSystems(self) -> typing.List[QFontDatabase.WritingSystem]:
        """
        https://doc.qt.io/qt-6/qrawfont.html#supportedWritingSystems

        **QList<QFontDatabase::WritingSystem>
        QRawFont::supportedWritingSystems() const**

        Returns a list of writing systems supported by the font according to
        designer supplied information in the font file. Please note that this
        does not guarantee support for a specific unicode point in the font. You
        can use the **supportsCharacter** () to check support for a single,
        specific character.

        **Note:** The list is determined based on the unicode ranges and
        codepage ranges set in the font's OS/2 table and requires such a table
        to be present in the underlying font file.

        **See also** **supportsCharacter** ().
        """
        ...

    @typing.overload
    def supportsCharacter(self, ucs4: int) -> bool:
        """
        https://doc.qt.io/qt-6/qrawfont.html#supportsCharacter

        **bool QRawFont::supportsCharacter(QChar character ) const**

        Returns `true` if the font has a glyph that corresponds to the given
        **character**.

        **See also** **supportedWritingSystems** ().
        """
        ...

    @typing.overload
    def supportsCharacter(self, character: str) -> bool:
        """
        https://doc.qt.io/qt-6/qrawfont.html#supportsCharacter-1

        **bool QRawFont::supportsCharacter(uint ucs4 ) const**

        This is an overloaded function.

        Returns `true` if the font has a glyph that corresponds to the UCS-4
        encoded character **ucs4**.

        **See also** **supportedWritingSystems** ().
        """
        ...

    def loadFromData(
        self,
        fontData: QtCore.QByteArray,
        pixelSize: float,
        hintingPreference: QFont.HintingPreference,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qrawfont.html#loadFromData

        **void QRawFont::loadFromData(const QByteArray & fontData , qreal
        pixelSize , QFont::HintingPreference hintingPreference )**

        Replaces the current **QRawFont**  with the font contained in the
        supplied **fontData** for the size (in pixels) given by **pixelSize** ,
        and using the hinting preference specified by **hintingPreference**.

        The **fontData** must contain a TrueType or OpenType font.

        **See also** **loadFromFile** ().
        """
        ...

    def loadFromFile(
        self,
        fileName: str,
        pixelSize: float,
        hintingPreference: QFont.HintingPreference,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qrawfont.html#loadFromFile

        **void QRawFont::loadFromFile(const QString & fileName , qreal pixelSize
        , QFont::HintingPreference hintingPreference )**

        Replaces the current **QRawFont**  with the contents of the file
        referenced by **fileName** for the size (in pixels) given by
        **pixelSize** , and using the hinting preference specified by
        **hintingPreference**.

        The file must reference a TrueType or OpenType font.

        **See also** **loadFromData** ().
        """
        ...

    def unitsPerEm(self) -> float:
        """
        https://doc.qt.io/qt-6/qrawfont.html#unitsPerEm

        **qreal QRawFont::unitsPerEm() const**

        Returns the number of design units define the width and height of the em
        square for this **QRawFont** . This value is used together with the
        pixel size when converting design metrics to pixel units, as the
        internal metrics are specified in design units and the pixel size gives
        the size of 1 em in pixels.

        **See also** **pixelSize** () and **setPixelSize** ().
        """
        ...

    def maxCharWidth(self) -> float:
        """
        https://doc.qt.io/qt-6/qrawfont.html#maxCharWidth

        **qreal QRawFont::maxCharWidth() const**

        Returns the width of the widest character in the font.

        **See also** **QFontMetricsF::maxWidth** ().
        """
        ...

    def averageCharWidth(self) -> float:
        """
        https://doc.qt.io/qt-6/qrawfont.html#averageCharWidth

        **qreal QRawFont::averageCharWidth() const**

        Returns the average character width of this **QRawFont**  in pixel
        units.

        **See also** **QFontMetricsF::averageCharWidth** ().
        """
        ...

    def xHeight(self) -> float:
        """
        https://doc.qt.io/qt-6/qrawfont.html#xHeight

        **qreal QRawFont::xHeight() const**

        Returns the xHeight of this **QRawFont**  in pixel units.

        This is often but not always the same as the height of the character
        'x'.

        **See also** **QFontMetricsF::xHeight** ().
        """
        ...

    def leading(self) -> float:
        """
        https://doc.qt.io/qt-6/qrawfont.html#leading

        **qreal QRawFont::leading() const**

        Returns the leading of this **QRawFont**  in pixel units.

        This is the natural inter-line spacing.

        **See also** **QFontMetricsF::leading** ().
        """
        ...

    def descent(self) -> float:
        """
        https://doc.qt.io/qt-6/qrawfont.html#descent

        **qreal QRawFont::descent() const**

        Returns the descent of this **QRawFont**  in pixel units.

        The descent is the distance from the base line to the lowest point
        characters extend to. In practice, some font designers break this rule,
        e.g. to accommodate an unusual character in an exotic language, so it is
        possible (though rare) that this value will be too small.

        **See also** **QFontMetricsF::descent** ().
        """
        ...

    def ascent(self) -> float:
        """
        https://doc.qt.io/qt-6/qrawfont.html#ascent

        **qreal QRawFont::ascent() const**

        Returns the ascent of this **QRawFont**  in pixel units.

        The ascent of a font is the distance from the baseline to the highest
        position characters extend to. In practice, some font designers break
        this rule, e.g. when they put more than one accent on top of a
        character, or to accommodate an unusual character in an exotic language,
        so it is possible (though rare) that this value will be too small.

        **See also** **QFontMetricsF::ascent** ().
        """
        ...

    def hintingPreference(self) -> QFont.HintingPreference:
        """
        https://doc.qt.io/qt-6/qrawfont.html#hintingPreference

        **QFont::HintingPreference QRawFont::hintingPreference() const**

        Returns the hinting preference used to construct this **QRawFont** .

        **See also** **QFont::hintingPreference** ().
        """
        ...

    def pixelSize(self) -> float:
        """
        https://doc.qt.io/qt-6/qrawfont.html#pixelSize

        **qreal QRawFont::pixelSize() const**

        Returns the pixel size set for this **QRawFont** . The pixel size
        affects how glyphs are rasterized, the size of glyphs returned by
        **pathForGlyph** (), and is used to convert internal metrics from design
        units to logical pixel units.

        **See also** **setPixelSize** ().
        """
        ...

    def setPixelSize(self, pixelSize: float) -> None:
        """
        https://doc.qt.io/qt-6/qrawfont.html#setPixelSize

        **void QRawFont::setPixelSize(qreal pixelSize )**

        Sets the pixel size with which this font should be rendered to
        **pixelSize**.

        **See also** **pixelSize** ().
        """
        ...

    def pathForGlyph(self, glyphIndex: int) -> QPainterPath:
        """
        https://doc.qt.io/qt-6/qrawfont.html#pathForGlyph

        **QPainterPath QRawFont::pathForGlyph(quint32 glyphIndex ) const**

        This function returns the shape of the glyph at a given **glyphIndex**
        in the underlying font if the **QRawFont**  is valid. Otherwise, it
        returns an empty **QPainterPath** .

        The returned glyph will always be unhinted.

        **See also** **alphaMapForGlyph** () and **QPainterPath::addText** ().
        """
        ...

    def alphaMapForGlyph(
        self,
        glyphIndex: int,
        antialiasingType: "QRawFont.AntialiasingType" = ...,
        transform: "QTransform" = ...,
    ) -> QImage:
        """
        https://doc.qt.io/qt-6/qrawfont.html#alphaMapForGlyph

        **QImage QRawFont::alphaMapForGlyph(quint32 glyphIndex ,
        QRawFont::AntialiasingType antialiasingType = SubPixelAntialiasing,
        const QTransform & transform = QTransform()) const**

        This function returns a rasterized image of the glyph at the given
        **glyphIndex** in the underlying font, using the **transform**
        specified. If the **QRawFont**  is not valid, this function will return
        an invalid **QImage** .

        If the font is a color font, then the resulting image will contain the
        rendered glyph at the current pixel size. In this case, the
        **antialiasingType** will be ignored.

        Otherwise, if **antialiasingType** is set to
        **QRawFont::SubPixelAntialiasing** , then the resulting image will be in
        **QImage::Format_RGB32**  and the RGB values of each pixel will
        represent the subpixel opacities of the pixel in the rasterization of
        the glyph. Otherwise, the image will be in the format of
        **QImage::Format_Indexed8**  and each pixel will contain the opacity of
        the pixel in the rasterization.

        **See also** **pathForGlyph** () and **QPainter::drawGlyphRun** ().
        """
        ...

    @typing.overload
    def advancesForGlyphIndexes(
        self, glyphIndexes: typing.Iterable[int], layoutFlags: "QRawFont.LayoutFlag"
    ) -> typing.List[QtCore.QPointF]:
        """
        https://doc.qt.io/qt-6/qrawfont.html#advancesForGlyphIndexes

        **[since 5.1] QList<QPointF> QRawFont::advancesForGlyphIndexes(const
        QList<quint32> & glyphIndexes , QRawFont::LayoutFlags layoutFlags )
        const**

        Returns the **QRawFont** 's advances for each of the **glyphIndexes** in
        pixel units. The advances give the distance from the position of a given
        glyph to where the next glyph should be drawn to make it appear as if
        the two glyphs are unspaced. How the advances are calculated is
        controlled by **layoutFlags**.

        **Note:** When `KernedAdvances` is requested, this function will apply
        kerning rules from the TrueType table `KERN`, if this is available in
        the font. In many modern fonts, kerning is handled through OpenType
        rules or AAT rules, which requires a full shaping step to be applied. To
        get the results of fully shaping the text, use **QTextLayout** .

        This function was introduced in Qt 5.1.

        **See also** **QTextLine::horizontalAdvance** (),
        **QFontMetricsF::horizontalAdvance** (), and **QTextLayout::glyphRuns**
        ().
        """
        ...

    @typing.overload
    def advancesForGlyphIndexes(
        self, glyphIndexes: typing.Iterable[int]
    ) -> typing.List[QtCore.QPointF]:
        """
        https://doc.qt.io/qt-6/qrawfont.html#advancesForGlyphIndexes-1

        **QList<QPointF> QRawFont::advancesForGlyphIndexes(const QList<quint32>
        & glyphIndexes ) const**

        This is an overloaded function.

        Returns the **QRawFont** 's advances for each of the **glyphIndexes** in
        pixel units. The advances give the distance from the position of a given
        glyph to where the next glyph should be drawn to make it appear as if
        the two glyphs are unspaced. The advance of each glyph is calculated
        separately.

        **See also** **QTextLine::horizontalAdvance** () and
        **QFontMetricsF::horizontalAdvance** ().
        """
        ...

    def glyphIndexesForString(self, text: str) -> typing.List[int]:
        """
        https://doc.qt.io/qt-6/qrawfont.html#glyphIndexesForString

        **QList<quint32> QRawFont::glyphIndexesForString(const QString & text )
        const**

        Converts the string of unicode points given by **text** to glyph indexes
        using the CMAP table in the underlying font, and returns a list
        containing the result.

        Note that, in cases where there are other tables in the font that affect
        the shaping of the text, the returned glyph indexes will not correctly
        represent the rendering of the text. To get the correctly shaped text,
        you can use **QTextLayout**  to lay out and shape the text, then call
        QTextLayout::glyphs() to get the set of glyph index list and
        **QRawFont**  pairs.

        **See also** **advancesForGlyphIndexes** (), **glyphIndexesForChars**
        (), **QGlyphRun** , **QTextLayout::glyphRuns** (), and
        **QTextFragment::glyphRuns** ().
        """
        ...

    def weight(self) -> int:
        """
        https://doc.qt.io/qt-6/qrawfont.html#weight

        **int QRawFont::weight() const**

        Returns the weight of this **QRawFont** .

        **See also** **QFont::weight** ().
        """
        ...

    def style(self) -> QFont.Style:
        """
        https://doc.qt.io/qt-6/qrawfont.html#style

        **QFont::Style QRawFont::style() const**

        Returns the style of this **QRawFont** .

        **See also** **QFont::style** ().
        """
        ...

    def styleName(self) -> str:
        """
        https://doc.qt.io/qt-6/qrawfont.html#styleName

        **QString QRawFont::styleName() const**

        Returns the style name of this **QRawFont** .

        **See also** **QFont::styleName** ().
        """
        ...

    def familyName(self) -> str:
        """
        https://doc.qt.io/qt-6/qrawfont.html#familyName

        **QString QRawFont::familyName() const**

        Returns the family name of this **QRawFont** .
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qrawfont.html#isValid

        **bool QRawFont::isValid() const**

        Returns `true` if the **QRawFont**  is valid and false otherwise.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtWidgets
from PyQt6 import QtCore


class QAbstractFormBuilder(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qabstractformbuilder.html

    **Detailed Description**

    QAbstractFormBuilder provides a standard interface and a default
    implementation for constructing forms from user interface files. It is not
    intended to be instantiated directly. Use the **QFormBuilder**  class to
    create user interfaces from UI files at run-time. For example:

    MyForm::MyForm(**QWidget**  *parent)
                    : **QWidget** (parent)
    {
                    **QFormBuilder**  builder;
                    **QFile**
    file(":/forms/myWidget.ui");
                    file.open(**QFile**
    ::ReadOnly);
                    **QWidget**  *myWidget = builder.load(&file,
    this);
                    file.close();

                    **QVBoxLayout**
    *layout = new **QVBoxLayout** ;
                    layout->addWidget(myWidget);
    setLayout(layout);
                }

    To override certain aspects of the form builder's behavior, subclass
    QAbstractFormBuilder and reimplement the relevant virtual functions:

    * **load** () handles reading of UI format files from arbitrary QIODevices,
    and construction of widgets from the XML data that they contain.
      *
    **save** () handles saving of widget details in UI format to arbitrary
    QIODevices.
      * **workingDirectory** () and **setWorkingDirectory** ()
    control the directory in which forms are held. The form builder looks for
    other resources on paths relative to this directory.

    The **QFormBuilder**  class is typically used by custom components and
    applications that embed **Qt Designer**. Standalone applications that need
    to dynamically generate user interfaces at run-time use the **QUiLoader** ,
    found in the **Qt UI Tools**  module.

    **See also** **Qt UI Tools** .
    """

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qabstractformbuilder.html#QAbstractFormBuilder-2

        **QAbstractFormBuilder::QAbstractFormBuilder()**

        Constructs a new form builder.
        """
        ...

    def errorString(self) -> str:
        """
        https://doc.qt.io/qt-6/qabstractformbuilder.html#errorString

        **[since 5.0] QString QAbstractFormBuilder::errorString() const**

        Returns a human-readable description of the last error occurred in
        **load** ().

        This function was introduced in Qt 5.0.

        **See also** **load** ().
        """
        ...

    def workingDirectory(self) -> QtCore.QDir:
        """
        https://doc.qt.io/qt-6/qabstractformbuilder.html#workingDirectory

        **QDir QAbstractFormBuilder::workingDirectory() const**

        Returns the current working directory of the form builder.

        **See also** **setWorkingDirectory** ().
        """
        ...

    def setWorkingDirectory(self, directory: QtCore.QDir) -> None:
        """
        https://doc.qt.io/qt-6/qabstractformbuilder.html#setWorkingDirectory

        **void QAbstractFormBuilder::setWorkingDirectory(const QDir & directory
        )**

        Sets the current working directory of the form builder to the specified
        **directory**.

        **See also** **workingDirectory** ().
        """
        ...

    def save(self, dev: QtCore.QIODevice, widget: QtWidgets.QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qabstractformbuilder.html#save

        **[virtual] void QAbstractFormBuilder::save(QIODevice * device , QWidget
        * widget )**

        Saves an XML representation of the given **widget** to the specified
        **device** in the standard UI file format.

        **Note:** Unlike when saving a form in Qt Designer, all property values
        are written. This is because, the state of whether a property value was
        modified or not isn't stored in the Qt property system. The widget that
        is being saved, could have been created dynamically, not loaded via
        **load** (), so in this case the form builder isn't aware of the list of
        changed properties. Also, there's no generic way to do this for widgets
        that were created dynamically.

        Therefore, you should remove properties that are not required from your
        resulting XML files, before loading them. Alternatively, if you already
        know which properties you want to save when you call this method, you
        can overload `computeProperties()` and return a filtered list of
        required properties. Otherwise, unexpected behavior may occur as some of
        these properties may depend on each other.

        **See also** **load** ().
        """
        ...

    def load(
        self, device: QtCore.QIODevice, parent: typing.Optional[QtWidgets.QWidget] = ...
    ) -> QtWidgets.QWidget:
        """
        https://doc.qt.io/qt-6/qabstractformbuilder.html#load

        **[virtual] QWidget *QAbstractFormBuilder::load(QIODevice * device ,
        QWidget * parent = nullptr)**

        Loads an XML representation of a widget from the given **device** , and
        constructs a new widget with the specified **parent**.

        **See also** **save** () and **errorString** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtBluetooth import *


class QLowEnergyDescriptorData(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qlowenergydescriptordata.html

    **Detailed Description**

    An object of this class provides a descriptor to be added to a
    **QLowEnergyCharacteristicData**  object via
    **QLowEnergyCharacteristicData::addDescriptor** ().

    **Note:** The member functions related to access permissions are only
    applicable to those types of descriptors for which the Bluetooth
    specification does not prescribe if and how their values can be accessed.

    **See also** **QLowEnergyCharacteristicData** , **QLowEnergyServiceData** ,
    and **QLowEnergyController::addService** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergydescriptordata.html#QLowEnergyDescripto
        rData

        **QLowEnergyDescriptorData::QLowEnergyDescriptorData()**

        Creates a new invalid object of this class.
        """
        ...

    @typing.overload
    def __init__(self, uuid: QBluetoothUuid, value: QtCore.QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergydescriptordata.html#QLowEnergyDescripto
        rData-1

        **QLowEnergyDescriptorData::QLowEnergyDescriptorData(const
        QBluetoothUuid & uuid , const QByteArray & value )**

        Creates a new object of this class with UUID and value being provided by
        **uuid** and **value** , respectively.
        """
        ...

    @typing.overload
    def __init__(self, other: "QLowEnergyDescriptorData") -> None:
        """
        https://doc.qt.io/qt-6/qlowenergydescriptordata.html#QLowEnergyDescripto
        rData-2

        **QLowEnergyDescriptorData::QLowEnergyDescriptorData(const
        QLowEnergyDescriptorData & other )**

        Constructs a new object of this class that is a copy of **other**.
        """
        ...

    def swap(self, other: "QLowEnergyDescriptorData") -> None:
        """
        https://doc.qt.io/qt-6/qlowenergydescriptordata.html#swap

        **void QLowEnergyDescriptorData::swap(QLowEnergyDescriptorData & other
        )**

        Swaps this object with **other**.
        """
        ...

    def writeConstraints(self) -> QBluetooth.AttAccessConstraint:
        """
        https://doc.qt.io/qt-6/qlowenergydescriptordata.html#writeConstraints

        **QBluetooth::AttAccessConstraints
        QLowEnergyDescriptorData::writeConstraints() const**

        Returns the constraints under which the value of this descriptor can be
        written. This value is only relevant if **isWritable** () returns
        `true`.
        """
        ...

    def isWritable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qlowenergydescriptordata.html#isWritable

        **bool QLowEnergyDescriptorData::isWritable() const**

        Returns `true` if the value of this descriptor is writable and `false`
        otherwise.
        """
        ...

    def setWritePermissions(
        self, writable: bool, constraints: QBluetooth.AttAccessConstraint = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergydescriptordata.html#setWritePermissions

        **void QLowEnergyDescriptorData::setWritePermissions(bool writable ,
        QBluetooth::AttAccessConstraints constraints =
        QBluetooth::AttAccessConstraints())**

        Specifies whether the value of this descriptor is **writable** and if
        so, under which **constraints**.

        **See also** **setReadPermissions** ().
        """
        ...

    def readConstraints(self) -> QBluetooth.AttAccessConstraint:
        """
        https://doc.qt.io/qt-6/qlowenergydescriptordata.html#readConstraints

        **QBluetooth::AttAccessConstraints
        QLowEnergyDescriptorData::readConstraints() const**

        Returns the constraints under which the value of this descriptor can be
        read. This value is only relevant if **isReadable** () returns `true`.
        """
        ...

    def isReadable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qlowenergydescriptordata.html#isReadable

        **bool QLowEnergyDescriptorData::isReadable() const**

        Returns `true` if the value of this descriptor is readable and `false`
        otherwise.
        """
        ...

    def setReadPermissions(
        self, readable: bool, constraints: QBluetooth.AttAccessConstraint = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergydescriptordata.html#setReadPermissions

        **void QLowEnergyDescriptorData::setReadPermissions(bool readable ,
        QBluetooth::AttAccessConstraints constraints =
        QBluetooth::AttAccessConstraints())**

        Specifies whether the value of this descriptor is **readable** and if
        so, under which **constraints**.

        **See also** **setWritePermissions** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qlowenergydescriptordata.html#isValid

        **bool QLowEnergyDescriptorData::isValid() const**

        Returns true if and only if this object has a non-null UUID.
        """
        ...

    def setUuid(self, uuid: QBluetoothUuid) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergydescriptordata.html#setUuid

        **void QLowEnergyDescriptorData::setUuid(const QBluetoothUuid & uuid )**

        Sets the UUID of this descriptor to **uuid**.

        **See also** **uuid** ().
        """
        ...

    def uuid(self) -> QBluetoothUuid:
        """
        https://doc.qt.io/qt-6/qlowenergydescriptordata.html#uuid

        **QBluetoothUuid QLowEnergyDescriptorData::uuid() const**

        Returns the UUID of this descriptor.

        **See also** **setUuid** ().
        """
        ...

    def setValue(self, value: QtCore.QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergydescriptordata.html#setValue

        **void QLowEnergyDescriptorData::setValue(const QByteArray & value )**

        Sets the value of this descriptor to **value**. It will be sent to a
        peer device exactly the way it is provided here, so callers need to take
        care of things such as endianness.

        **See also** **value** ().
        """
        ...

    def value(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qlowenergydescriptordata.html#value

        **QByteArray QLowEnergyDescriptorData::value() const**

        Returns the value of this descriptor.

        **See also** **setValue** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtCore import *


class QTranslator(QObject):
    """
    https://doc.qt.io/qt-6/qtranslator.html

    **Detailed Description**

    An object of this class contains a set of translations from a source
    language to a target language. QTranslator provides functions to look up
    translations in a translation file. Translation files are created using **Qt
    Linguist** .

    The most common use of QTranslator is to: load a translation file, and
    install it using **QCoreApplication::installTranslator** ().

    Here's an example `main()` function using the QTranslator:

    int main(int argc, char *argv[])
        {
            **QApplication**  app(argc,
    argv);

            **QTranslator**  translator;
            // look up e.g.
    :/i18n/myapp_de.qm
            if (translator.load(**QLocale** (),
    QLatin1String("myapp"), QLatin1String("_"), QLatin1String(":/i18n")))
    **QCoreApplication** ::installTranslator(&translator);
    **QPushButton**  hello(**QCoreApplication** ::translate("main", "Hello
    world!"));
            hello.resize(100, 30);

            hello.show();
    return app.exec();
        }

    Note that the translator must be created **before** the application's
    widgets.

    Most applications will never need to do anything else with this class. The
    other functions provided by this class are useful for applications that work
    on translator files.

    **Looking up Translations**

    It is possible to look up a translation using **translate** () (as **tr** ()
    and **QCoreApplication::translate** () do). The **translate** () function
    takes up to three parameters:

    * The **context** \\- usually the class name for the **tr** () caller.
      *
    The **source text** \\- usually the argument to **tr** ().
      * The
    **disambiguation** \\- an optional string that helps disambiguate different
    uses of the same text in the same context.

    For example, the "Cancel" in a dialog might have "Anuluj" when the program
    runs in Polish (in this case the source text would be "Cancel"). The context
    would (normally) be the dialog's class name; there would normally be no
    comment, and the translated text would be "Anuluj".

    But it's not always so simple. The Spanish version of a printer dialog with
    settings for two-sided printing and binding would probably require both
    "Activado" and "Activada" as translations for "Enabled". In this case the
    source text would be "Enabled" in both cases, and the context would be the
    dialog's class name, but the two items would have disambiguations such as
    "two-sided printing" for one and "binding" for the other. The disambiguation
    enables the translator to choose the appropriate gender for the Spanish
    version, and enables Qt to distinguish between translations.

    **Using Multiple Translations**

    Multiple translation files can be installed in an application. Translations
    are searched for in the reverse order in which they were installed, so the
    most recently installed translation file is searched for translations first
    and the earliest translation file is searched last. The search stops as soon
    as a translation containing a matching string is found.

    This mechanism makes it possible for a specific translation to be "selected"
    or given priority over the others; simply uninstall the translator from the
    application by passing it to the **QCoreApplication::removeTranslator** ()
    function and reinstall it with **QCoreApplication::installTranslator** ().
    It will then be the first translation to be searched for matching strings.

    **See also** **QCoreApplication::installTranslator** (),
    **QCoreApplication::removeTranslator** (), **QObject::tr** (),
    **QCoreApplication::translate** (), **I18N Example** , **Hello tr()
    Example** , **Arrow Pad Example** , and **Troll Print Example** .
    """

    def __init__(self, parent: typing.Optional[QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtranslator.html#QTranslator

        **QTranslator::QTranslator(QObject * parent = nullptr)**

        Constructs an empty message file object with parent **parent** that is
        not connected to any file.
        """
        ...

    def filePath(self) -> str:
        """
        https://doc.qt.io/qt-6/qtranslator.html#filePath

        **[since 5.15] QString QTranslator::filePath() const**

        Returns the path of the loaded translation file.

        The file path is empty if no translation was loaded yet, the loading
        failed, or if the translation was not loaded from a file.

        This function was introduced in Qt 5.15.
        """
        ...

    def language(self) -> str:
        """
        https://doc.qt.io/qt-6/qtranslator.html#language

        **[since 5.15] QString QTranslator::language() const**

        Returns the target language as stored in the translation file.

        This function was introduced in Qt 5.15.
        """
        ...

    def loadFromData(self, data: bytes, directory: str = ...) -> bool:
        ...

    @typing.overload
    def load(
        self,
        fileName: str,
        directory: str = ...,
        searchDelimiters: str = ...,
        suffix: str = ...,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qtranslator.html#load

        **bool QTranslator::load(const QString & filename , const QString &
        directory = QString(), const QString & search_delimiters = QString(),
        const QString & suffix = QString())**

        Loads **filename** \\+ **suffix** (".qm" if the **suffix** is not
        specified), which may be an absolute file name or relative to
        **directory**. Returns `true` if the translation is successfully loaded;
        otherwise returns `false`.

        If **directory** is not specified, the current directory is used (i.e.,
        as **currentPath** ()).

        The previous contents of this translator object are discarded.

        If the file name does not exist, other file names are tried in the
        following order:

        1. File name without **suffix** appended.
          2. File name with text after
        a character in **search_delimiters** stripped ("_." is the default for
        **search_delimiters** if it is an empty string) and **suffix**.
          3.
        File name stripped without **suffix** appended.
          4. File name stripped
        further, etc.

        For example, an application running in the fr_CA locale (French-speaking
        Canada) might call load("foo.fr_ca", "/opt/foolib"). load() would then
        try to open the first existing readable file from this list:

        1. `/opt/foolib/foo.fr_ca.qm`
          2. `/opt/foolib/foo.fr_ca`
          3.
        `/opt/foolib/foo.fr.qm`
          4. `/opt/foolib/foo.fr`
          5.
        `/opt/foolib/foo.qm`
          6. `/opt/foolib/foo`

        Usually, it is better to use the QTranslator::load(const **QLocale**  &,
        const **QString**  &, const **QString**  &, const **QString**  &, const
        **QString**  &) function instead, because it uses
        **QLocale::uiLanguages** () and not simply the locale name, which refers
        to the formatting of dates and numbers and not necessarily the UI
        language.
        """
        ...

    @typing.overload
    def load(
        self,
        locale: QLocale,
        fileName: str,
        prefix: str = ...,
        directory: str = ...,
        suffix: str = ...,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qtranslator.html#load-1

        **bool QTranslator::load(const QLocale & locale , const QString &
        filename , const QString & prefix = QString(), const QString & directory
        = QString(), const QString & suffix = QString())**

        Loads **filename** \\+ **prefix** \\+ **ui language name**  \\+ **suffix**
        (".qm" if the **suffix** is not specified), which may be an absolute
        file name or relative to **directory**. Returns `true` if the
        translation is successfully loaded; otherwise returns `false`.

        The previous contents of this translator object are discarded.

        If the file name does not exist, other file names are tried in the
        following order:

        1. File name without **suffix** appended.
          2. File name with ui
        language part after a "_" character stripped and **suffix**.
          3. File
        name with ui language part stripped without **suffix** appended.
          4.
        File name with ui language part stripped further, etc.

        For example, an application running in the **locale** with the following
        **ui languages**  \\- "es", "fr-CA", "de" might call load(QLocale(),
        "foo", ".", "/opt/foolib", ".qm"). load() would replace '-' (dash) with
        '_' (underscore) in the ui language and then try to open the first
        existing readable file from this list:

        1. `/opt/foolib/foo.es.qm`
          2. `/opt/foolib/foo.es`
          3.
        `/opt/foolib/foo.fr_CA.qm`
          4. `/opt/foolib/foo.fr_CA`
          5.
        `/opt/foolib/foo.fr.qm`
          6. `/opt/foolib/foo.fr`
          7.
        `/opt/foolib/foo.de.qm`
          8. `/opt/foolib/foo.de`
          9.
        `/opt/foolib/foo.qm`
          10. `/opt/foolib/foo`.
          11. `/opt/foolib/foo`

        On operating systems where file system is case sensitive,
        **QTranslator**  also tries to load a lower-cased version of the locale
        name.
        """
        ...

    def isEmpty(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtranslator.html#isEmpty

        **[virtual] bool QTranslator::isEmpty() const**

        Returns `true` if this translator is empty, otherwise returns `false`.
        This function works with stripped and unstripped translation files.
        """
        ...

    def translate(
        self,
        context: str,
        sourceText: str,
        disambiguation: typing.Optional[str] = ...,
        n: int = ...,
    ) -> str:
        """
        https://doc.qt.io/qt-6/qtranslator.html#translate

        **[virtual] QString QTranslator::translate(const char * context , const
        char * sourceText , const char * disambiguation = nullptr, int n = -1)
        const**

        Returns the translation for the key ( **context** , **sourceText** ,
        **disambiguation** ). If none is found, also tries ( **context** ,
        **sourceText** , ""). If that still fails, returns a null string.

        **Note:** Incomplete translations may result in unexpected behavior: If
        no translation for ( **context** , **sourceText** , "") is provided, the
        method might in this case actually return a translation for a different
        **disambiguation**.

        If **n** is not -1, it is used to choose an appropriate form for the
        translation (e.g. "%n file found" vs. "%n files found").

        If you need to programmatically insert translations into a
        **QTranslator** , this function can be reimplemented.

        **See also** **load** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtSensors import *


class QRotationSensor(QSensor):
    """
    https://doc.qt.io/qt-6/qrotationsensor.html

    **Detailed Description**

    The only behavioural difference is that this class sets the type properly.

    This class also features a **reading** () function that returns a
    **QRotationReading**  instead of a **QSensorReading** .

    For details about how the sensor works, see **QRotationReading** .

    **See also** **QRotationReading** .
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qrotationsensor.html#QRotationSensor

        **QRotationSensor::QRotationSensor(QObject * parent = nullptr)**

        Construct the sensor as a child of **parent**.
        """
        ...

    def setHasZ(self, hasZ: bool) -> None:
        """
        https://doc.qt.io/qt-6/qrotationsensor.html#setHasZ

        **[since 5.1] void QRotationSensor::setHasZ(bool hasZ )**

        Sets whether the z angle is available to **hasZ**. This is to be called
        from the backend. By default the **hasZ**  property is true, so a
        backend only has to call this if its rotation sensor can not report z
        angles.

        This function was introduced in Qt 5.1.

        **See also** **hasZ** ().
        """
        ...

    def hasZ(self) -> bool:
        """
        https://doc.qt.io/qt-6/qrotationsensor.html#hasZ-prop

        **[read-only] hasZ : const bool**

        This property holds a value indicating if the z angle is available.

        Returns true if z is available. Returns false if z is not available.

        **Access functions:**

        bool **hasZ** () const

        **Notifier signal:**

        void **hasZChanged** (bool **hasZ** )

        **Member Function Documentation**
        """
        ...

    def reading(self) -> QRotationReading:
        """
        https://doc.qt.io/qt-6/qrotationsensor.html#reading

        **QRotationReading *QRotationSensor::reading() const**

        Returns the reading class for this sensor.

        **See also** **QSensor::reading** ().
        """
        ...

    @property
    def hasZChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
from PyQt6 import QtCore
from PyQt6.QtQml import *
import enum


class QQmlImageProviderBase(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qqmlimageproviderbase.html

    **Detailed Description**

    Image providers must be registered with the QML engine. The only information
    the QML engine knows about image providers is the type of image data they
    provide. To use an image provider to acquire image data, you must cast the
    QQmlImageProviderBase pointer to a **QQuickImageProvider**  pointer.

    **See also** **QQuickImageProvider**  and **QQuickTextureFactory** .
    """

    class Flag(enum.Flag):
        ForceAsynchronousImageLoading: QQmlImageProviderBase = ...

    class ImageType(enum.Enum):
        Image: QQmlImageProviderBase = ...
        Pixmap: QQmlImageProviderBase = ...
        Texture: QQmlImageProviderBase = ...
        ImageResponse: QQmlImageProviderBase = ...

    def flags(self) -> "QQmlImageProviderBase.Flag":
        """
        https://doc.qt.io/qt-6/qqmlimageproviderbase.html#flags

        **[pure virtual] QQmlImageProviderBase::Flags
        QQmlImageProviderBase::flags() const**

        Implement this to return the properties of this image provider.
        """
        ...

    def imageType(self) -> "QQmlImageProviderBase.ImageType":
        """
        https://doc.qt.io/qt-6/qqmlimageproviderbase.html#imageType

        **[pure virtual] QQmlImageProviderBase::ImageType
        QQmlImageProviderBase::imageType() const**

        Implement this method to return the image type supported by this image
        provider.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtXml import *


class QDomNotation(QDomNode):
    """
    https://doc.qt.io/qt-6/qdomnotation.html

    **Detailed Description**

    A notation either declares, by name, the format of an unparsed entity (see
    section 4.7 of the XML 1.0 specification), or is used for formal declaration
    of processing instruction targets (see section 2.6 of the XML 1.0
    specification).

    DOM does not support editing notation nodes; they are therefore read-only.

    A notation node does not have any parent.

    You can retrieve the **publicId** () and **systemId** () from a notation
    node.

    For further information about the Document Object Model see **Level 1**  and
    **Level 2 Core** . For a more general introduction of the DOM implementation
    see the **QDomDocument**  documentation.
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qdomnotation.html#QDomNotation

        **QDomNotation::QDomNotation()**

        Constructor.
        """
        ...

    @typing.overload
    def __init__(self, x: "QDomNotation") -> None:
        """
        https://doc.qt.io/qt-6/qdomnotation.html#QDomNotation-1

        **QDomNotation::QDomNotation(const QDomNotation & x )**

        Constructs a copy of **x**.

        The data of the copy is shared (shallow copy): modifying one node will
        also change the other. If you want to make a deep copy, use
        **cloneNode** ().
        """
        ...

    def nodeType(self) -> QDomNode.NodeType:
        """
        https://doc.qt.io/qt-6/qdomnotation.html#nodeType

        **QDomNode::NodeType QDomNotation::nodeType() const**

        Returns `NotationNode`.
        """
        ...

    def systemId(self) -> str:
        """
        https://doc.qt.io/qt-6/qdomnotation.html#systemId

        **QString QDomNotation::systemId() const**

        Returns the system identifier of this notation.
        """
        ...

    def publicId(self) -> str:
        """
        https://doc.qt.io/qt-6/qdomnotation.html#publicId

        **QString QDomNotation::publicId() const**

        Returns the public identifier of this notation.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtNetwork import *
import enum


class QNetworkAddressEntry(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qnetworkaddressentry.html

    **Detailed Description**

    Each network interface can contain zero or more IP addresses, which in turn
    can be associated with a netmask and/or a broadcast address (depending on
    support from the operating system).

    This class represents one such group.
    """

    class DnsEligibilityStatus(enum.Enum):
        DnsEligibilityUnknown: QNetworkAddressEntry = ...
        DnsIneligible: QNetworkAddressEntry = ...
        DnsEligible: QNetworkAddressEntry = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkaddressentry.html#QNetworkAddressEntry

        **QNetworkAddressEntry::QNetworkAddressEntry()**

        Constructs an empty QNetworkAddressEntry object.
        """
        ...

    @typing.overload
    def __init__(self, other: "QNetworkAddressEntry") -> None:
        """
        https://doc.qt.io/qt-6/qnetworkaddressentry.html#QNetworkAddressEntry-1

        **QNetworkAddressEntry::QNetworkAddressEntry(const QNetworkAddressEntry
        & other )**

        Constructs a QNetworkAddressEntry object that is a copy of the object
        **other**.
        """
        ...

    def isTemporary(self) -> bool:
        """
        https://doc.qt.io/qt-6/qnetworkaddressentry.html#isTemporary

        **[since 5.11] bool QNetworkAddressEntry::isTemporary() const**

        Returns `true` if this address is temporary on this interface, `false`
        if it's permanent.

        This function was introduced in Qt 5.11.

        **See also** **isLifetimeKnown** (), **validityLifetime** (), and
        **isPermanent** ().
        """
        ...

    def isPermanent(self) -> bool:
        """
        https://doc.qt.io/qt-6/qnetworkaddressentry.html#isPermanent

        **[since 5.11] bool QNetworkAddressEntry::isPermanent() const**

        Returns `true` if this address is permanent on this interface, `false`
        if it's temporary. A permanent address is one which has no expiration
        time and is often static (manually configured).

        If this information could not be determined, this function returns
        `true`.

        **Note:** Depending on the operating system and the networking
        configuration tool, it is possible for a temporary address to be
        interpreted as permanent, if the tool did not inform the details
        correctly to the operating system.

        This function was introduced in Qt 5.11.

        **See also** **isLifetimeKnown** (), **validityLifetime** (), and
        **isTemporary** ().
        """
        ...

    def clearAddressLifetime(self) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkaddressentry.html#clearAddressLifetime

        **[since 5.11] void QNetworkAddressEntry::clearAddressLifetime()**

        Resets both the preferred and valid lifetimes for this address. After
        this call, **isLifetimeKnown** () will return `false`.

        This function was introduced in Qt 5.11.

        **See also** **preferredLifetime** (), **validityLifetime** (),
        **isLifetimeKnown** (), and **setAddressLifetime** ().
        """
        ...

    def setAddressLifetime(
        self, preferred: QtCore.QDeadlineTimer, validity: QtCore.QDeadlineTimer
    ) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkaddressentry.html#setAddressLifetime

        **[since 5.11] void
        QNetworkAddressEntry::setAddressLifetime(QDeadlineTimer preferred ,
        QDeadlineTimer validity )**

        Sets both the preferred and valid lifetimes for this address to the
        **preferred** and **validity** deadlines, respectively. After this call,
        **isLifetimeKnown** () will return `true`, even if both parameters are
        **QDeadlineTimer::Forever** .

        This function was introduced in Qt 5.11.

        **See also** **preferredLifetime** (), **validityLifetime** (),
        **isLifetimeKnown** (), and **clearAddressLifetime** ().
        """
        ...

    def validityLifetime(self) -> QtCore.QDeadlineTimer:
        """
        https://doc.qt.io/qt-6/qnetworkaddressentry.html#validityLifetime

        **[since 5.11] QDeadlineTimer QNetworkAddressEntry::validityLifetime()
        const**

        Returns the deadline when this address becomes invalid and will be
        removed from the networking stack, if known. If the address lifetime is
        not known (see **isLifetimeKnown** ()), this function always returns
        **QDeadlineTimer::Forever** .

        While an address is valid, it will be accepted by the operating system
        as a valid destination address for this machine. Whether it is used as a
        source address for new, outgoing packets is controlled by, among other
        rules, the preferred lifetime (see **preferredLifetime** ()).

        This function was introduced in Qt 5.11.

        **See also** **preferredLifetime** (), **isLifetimeKnown** (),
        **setAddressLifetime** (), and **clearAddressLifetime** ().
        """
        ...

    def preferredLifetime(self) -> QtCore.QDeadlineTimer:
        """
        https://doc.qt.io/qt-6/qnetworkaddressentry.html#preferredLifetime

        **[since 5.11] QDeadlineTimer QNetworkAddressEntry::preferredLifetime()
        const**

        Returns the deadline when this address becomes deprecated (no longer
        preferred), if known. If the address lifetime is not known (see
        **isLifetimeKnown** ()), this function always returns
        **QDeadlineTimer::Forever** .

        While an address is preferred, it may be used by the operating system as
        the source address for new, outgoing packets. After it becomes
        deprecated, it will remain valid for incoming packets for a while longer
        until finally removed (see **validityLifetime** ()).

        This function was introduced in Qt 5.11.

        **See also** **validityLifetime** (), **isLifetimeKnown** (),
        **setAddressLifetime** (), and **clearAddressLifetime** ().
        """
        ...

    def isLifetimeKnown(self) -> bool:
        """
        https://doc.qt.io/qt-6/qnetworkaddressentry.html#isLifetimeKnown

        **[since 5.11] bool QNetworkAddressEntry::isLifetimeKnown() const**

        Returns `true` if the address lifetime is known, `false` if not. If the
        lifetime is not known, both **preferredLifetime** () and
        **validityLifetime** () will return **QDeadlineTimer::Forever** .

        This function was introduced in Qt 5.11.

        **See also** **preferredLifetime** (), **validityLifetime** (),
        **setAddressLifetime** (), and **clearAddressLifetime** ().
        """
        ...

    def setDnsEligibility(
        self, status: "QNetworkAddressEntry.DnsEligibilityStatus"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkaddressentry.html#setDnsEligibility

        **[since 5.11] void QNetworkAddressEntry::setDnsEligibility(QNetworkAddr
        essEntry::DnsEligibilityStatus status )**

        Sets the DNS eligibility flag for this address to **status**.

        This function was introduced in Qt 5.11.

        **See also** **dnsEligibility** ().
        """
        ...

    def dnsEligibility(self) -> "QNetworkAddressEntry.DnsEligibilityStatus":
        """
        https://doc.qt.io/qt-6/qnetworkaddressentry.html#dnsEligibility

        **[since 5.11] QNetworkAddressEntry::DnsEligibilityStatus
        QNetworkAddressEntry::dnsEligibility() const**

        Returns whether this address is eligible for publication in the Domain
        Name System (DNS) or similar name resolution mechanisms.

        In general, an address is suitable for publication if it is an address
        this machine will be reached at for an indeterminate amount of time,
        though it need not be permanent. For example, addresses obtained via
        DHCP are often eligible, but cryptographically-generated temporary IPv6
        addresses are not.

        On some systems, **QNetworkInterface**  will need to heuristically
        determine which addresses are eligible.

        This function was introduced in Qt 5.11.

        **See also** **isLifetimeKnown** (), **isPermanent** (), and
        **setDnsEligibility** ().
        """
        ...

    def swap(self, other: "QNetworkAddressEntry") -> None:
        """
        https://doc.qt.io/qt-6/qnetworkaddressentry.html#swap

        **[since 5.0] void QNetworkAddressEntry::swap(QNetworkAddressEntry &
        other )**

        Swaps this network address entry instance with **other**. This function
        is very fast and never fails.

        This function was introduced in Qt 5.0.
        """
        ...

    def setPrefixLength(self, length: int) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkaddressentry.html#setPrefixLength

        **void QNetworkAddressEntry::setPrefixLength(int length )**

        Sets the prefix length of this IP address to **length**. The value of
        **length** must be valid for this type of IP address: between 0 and 32
        for IPv4 addresses, between 0 and 128 for IPv6 addresses. Setting to any
        invalid value is equivalent to setting to -1, which means "no prefix
        length".

        Setting the prefix length also sets the netmask (see **netmask** ()).

        **See also** **prefixLength** () and **setNetmask** ().
        """
        ...

    def prefixLength(self) -> int:
        """
        https://doc.qt.io/qt-6/qnetworkaddressentry.html#prefixLength

        **int QNetworkAddressEntry::prefixLength() const**

        Returns the prefix length of this IP address. The prefix length matches
        the number of bits set to 1 in the netmask (see **netmask** ()). For
        IPv4 addresses, the value is between 0 and 32. For IPv6 addresses, it's
        contained between 0 and 128 and is the preferred form of representing
        addresses.

        This function returns -1 if the prefix length could not be determined
        (i.e., **netmask** () returns a null QHostAddress()).

        **See also** **setPrefixLength** () and **netmask** ().
        """
        ...

    def setBroadcast(
        self, newBroadcast: typing.Union[QHostAddress, QHostAddress.SpecialAddress]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkaddressentry.html#setBroadcast

        **void QNetworkAddressEntry::setBroadcast(const QHostAddress &
        newBroadcast )**

        Sets the broadcast IP address of this **QNetworkAddressEntry**  object
        to **newBroadcast**.

        **See also** **broadcast** ().
        """
        ...

    def broadcast(self) -> QHostAddress:
        """
        https://doc.qt.io/qt-6/qnetworkaddressentry.html#broadcast

        **QHostAddress QNetworkAddressEntry::broadcast() const**

        Returns the broadcast address associated with the IPv4 address and
        netmask. It can usually be derived from those two by setting to 1 the
        bits of the IP address where the netmask contains a 0. (In other words,
        by bitwise-OR'ing the IP address with the inverse of the netmask)

        This member is always empty for IPv6 addresses, since the concept of
        broadcast has been abandoned in that system in favor of multicast. In
        particular, the group of hosts corresponding to all the nodes in the
        local network can be reached by the "all-nodes" special multicast group
        (address FF02::1).

        **See also** **setBroadcast** ().
        """
        ...

    def setNetmask(
        self, newNetmask: typing.Union[QHostAddress, QHostAddress.SpecialAddress]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkaddressentry.html#setNetmask

        **void QNetworkAddressEntry::setNetmask(const QHostAddress & newNetmask
        )**

        Sets the netmask that this **QNetworkAddressEntry**  object contains to
        **newNetmask**. Setting the netmask also sets the prefix length to match
        the new netmask.

        **See also** **netmask** () and **setPrefixLength** ().
        """
        ...

    def netmask(self) -> QHostAddress:
        """
        https://doc.qt.io/qt-6/qnetworkaddressentry.html#netmask

        **QHostAddress QNetworkAddressEntry::netmask() const**

        Returns the netmask associated with the IP address. The netmask is
        expressed in the form of an IP address, such as 255.255.0.0.

        For IPv6 addresses, the prefix length is converted to an address where
        the number of bits set to 1 is equal to the prefix length. For a prefix
        length of 64 bits (the most common value), the netmask will be expressed
        as a **QHostAddress**  holding the address FFFF:FFFF:FFFF:FFFF::

        **See also** **setNetmask** () and **prefixLength** ().
        """
        ...

    def setIp(
        self, newIp: typing.Union[QHostAddress, QHostAddress.SpecialAddress]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkaddressentry.html#setIp

        **void QNetworkAddressEntry::setIp(const QHostAddress & newIp )**

        Sets the IP address the **QNetworkAddressEntry**  object contains to
        **newIp**.

        **See also** **ip** ().
        """
        ...

    def ip(self) -> QHostAddress:
        """
        https://doc.qt.io/qt-6/qnetworkaddressentry.html#ip

        **QHostAddress QNetworkAddressEntry::ip() const**

        This function returns one IPv4 or IPv6 address found, that was found in
        a network interface.

        **See also** **setIp** ().
        """
        ...
